Ans="""
'''

import java.awt.BorderLayout;
import java.awt.EventQueue;

import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.border.EmptyBorder;
import javax.swing.GroupLayout;
import javax.swing.GroupLayout.Alignment;
import javax.swing.JLabel;
import javax.swing.JOptionPane;

import java.awt.Color;
import java.awt.Font;
import javax.swing.JTextField;
import javax.swing.JButton;
import javax.swing.LayoutStyle.ComponentPlacement;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

public class IssueBookForm extends JFrame {
	static IssueBookForm frame;
	private JPanel contentPane;
	private JTextField textField_1;
	private JTextField textField_2;
	private JTextField textField_3;
	private JTextField textField_4;

	/**
	 * Launch the application.
	 */
	public static void main(String[] args) {
		EventQueue.invokeLater(new Runnable() {
			public void run() {
				try {
					frame = new IssueBookForm();
					frame.setVisible(true);
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		});
	}

	/**
	 * Create the frame.
	 */
	public IssueBookForm() {
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		setBounds(100, 100, 438, 414);
		contentPane = new JPanel();
		contentPane.setBorder(new EmptyBorder(5, 5, 5, 5));
		setContentPane(contentPane);
		
		JLabel lblNewLabel = new JLabel("Issue Book ");
		lblNewLabel.setFont(new Font("Tahoma", Font.PLAIN, 18));
		lblNewLabel.setForeground(Color.GRAY);
		
		JLabel lblBookName = new JLabel("Book Callno:");
		
		textField_1 = new JTextField();
		textField_1.setColumns(10);
		
		textField_2 = new JTextField();
		textField_2.setColumns(10);
		
		textField_3 = new JTextField();
		textField_3.setColumns(10);
		
		textField_4 = new JTextField();
		textField_4.setColumns(10);
		
		JLabel lblStudentId = new JLabel("Student Id:");
		
		JLabel lblStudentName = new JLabel("Student Name:");
		
		JLabel lblStudentContact = new JLabel("Student Contact:");
		
		JButton btnIssueBook = new JButton("Issue Book");
		btnIssueBook.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				
			String bookcallno=textField_1.getText();
			int studentid=Integer.parseInt(textField_2.getText());
			String studentname=textField_3.getText();
			String studentcontact=textField_4.getText();
			
			if(IssueBookDao.checkBook(bookcallno)){
			
			int i=IssueBookDao.save(bookcallno, studentid, studentname, studentcontact);
			if(i>0){
				JOptionPane.showMessageDialog(IssueBookForm.this,"Book issued successfully!");
				LibrarianSuccess.main(new String[]{});
				frame.dispose();
				
			}else{
				JOptionPane.showMessageDialog(IssueBookForm.this,"Sorry, unable to issue!");
			}//end of save if-else
			
			}else{
				JOptionPane.showMessageDialog(IssueBookForm.this,"Sorry, Callno doesn't exist!");
			}//end of checkbook if-else
			
			}
		});
		
		JButton btnBack = new JButton("Back");
		btnBack.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				LibrarianSuccess.main(new String[]{});
				frame.dispose();
			}
		});
		
		JLabel lblNewLabel_1 = new JLabel("Note: Please check Student ID Carefully before issuing book!");
		lblNewLabel_1.setFont(new Font("Tahoma", Font.PLAIN, 13));
		lblNewLabel_1.setForeground(Color.RED);
		GroupLayout gl_contentPane = new GroupLayout(contentPane);
		gl_contentPane.setHorizontalGroup(
			gl_contentPane.createParallelGroup(Alignment.LEADING)
				.addGroup(gl_contentPane.createSequentialGroup()
					.addContainerGap(10, Short.MAX_VALUE)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.LEADING)
						.addGroup(gl_contentPane.createSequentialGroup()
							.addGroup(gl_contentPane.createParallelGroup(Alignment.LEADING)
								.addComponent(lblBookName)
								.addComponent(lblStudentId)
								.addComponent(lblStudentName, GroupLayout.PREFERRED_SIZE, 108, GroupLayout.PREFERRED_SIZE)
								.addComponent(lblStudentContact, GroupLayout.PREFERRED_SIZE, 100, GroupLayout.PREFERRED_SIZE))
							.addGap(10)
							.addGroup(gl_contentPane.createParallelGroup(Alignment.LEADING)
								.addComponent(textField_2, GroupLayout.PREFERRED_SIZE, 172, GroupLayout.PREFERRED_SIZE)
								.addComponent(textField_1, GroupLayout.PREFERRED_SIZE, 172, GroupLayout.PREFERRED_SIZE)
								.addComponent(textField_3, GroupLayout.PREFERRED_SIZE, 172, GroupLayout.PREFERRED_SIZE)
								.addComponent(textField_4, GroupLayout.PREFERRED_SIZE, 172, GroupLayout.PREFERRED_SIZE))
							.addGap(48))
						.addGroup(Alignment.TRAILING, gl_contentPane.createSequentialGroup()
							.addGap(20)
							.addGroup(gl_contentPane.createParallelGroup(Alignment.TRAILING)
								.addComponent(lblNewLabel_1)
								.addGroup(gl_contentPane.createSequentialGroup()
									.addComponent(btnIssueBook, GroupLayout.PREFERRED_SIZE, 100, GroupLayout.PREFERRED_SIZE)
									.addGap(47)
									.addComponent(btnBack)))
							.addGap(100))))
				.addGroup(gl_contentPane.createSequentialGroup()
					.addGap(146)
					.addComponent(lblNewLabel)
					.addContainerGap(235, Short.MAX_VALUE))
		);
		gl_contentPane.setVerticalGroup(
			gl_contentPane.createParallelGroup(Alignment.TRAILING)
				.addGroup(gl_contentPane.createSequentialGroup()
					.addGap(37)
					.addComponent(lblNewLabel)
					.addGap(43)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.BASELINE)
						.addComponent(lblBookName)
						.addComponent(textField_1, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
					.addGap(28)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.BASELINE)
						.addComponent(lblStudentId)
						.addComponent(textField_2, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
					.addGap(28)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.BASELINE)
						.addComponent(lblStudentName)
						.addComponent(textField_3, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
					.addGap(26)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.BASELINE)
						.addComponent(lblStudentContact)
						.addComponent(textField_4, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
					.addPreferredGap(ComponentPlacement.UNRELATED)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.BASELINE)
						.addComponent(btnIssueBook, GroupLayout.PREFERRED_SIZE, 31, GroupLayout.PREFERRED_SIZE)
						.addComponent(btnBack))
					.addGap(18)
					.addComponent(lblNewLabel_1)
					.addGap(25))
		);
		contentPane.setLayout(gl_contentPane);
	}
}

'''
"""



Ans="""

Using Data Caching
The most important object in caching mechanism is cache object. The Cache object is the fundamental object for all caching in the ASP.NET Framework.

The cache object can be accessed in every page of your application. It works same as Session object. Storing and retrieving the object in cache is very easy.

Cache["Key"]="Item";

Normally you store database object in Cache, so it will reduce the database calling again and again.

Some of the important methods of Cache object are as follows:

    Add: It adds a new item to the cache.
    Get: It returns a particular item from the cache.
    Insert: It is used to insert a new item into the cache. This method replaces the already exists item.
    Remove: This method is used to remove an item from the cache.

Cache is a powerful object, you can add into it DataSet, DataTable, ArrayList etc.

Now let’s take an example and create a web application in which we will take two web pages. In first page, we will add the dataset object into the cache and then access this cached data from second page.

FirstPage.aspx.cs

using System;
using System.Configuration;
using System.Data;
using System.Data.SqlClient;
public partial class FirstPage : System.Web.UI.Page
{
    SqlConnection conn;
    SqlDataAdapter adapter;
    DataSet ds;
    
    string cs = ConfigurationManager.ConnectionStrings["conString"].ConnectionString;
    protected void Page_Load(object sender, EventArgs e)
    {
        ds=new DataSet();
        conn = new SqlConnection(cs);
        adapter = new SqlDataAdapter("select * from tblEmps", conn);      
        adapter.Fill(ds);
        Cache["Data"] = ds;       
    }
    
    protected void Button1_Click(object sender, EventArgs e)
    {
        Response.Redirect("SecondPage.aspx");
    }
}

Now you can use Cache["Data"] object in any web page of your application. Cache returns the Object type, therefore you must typecast to underlying data type.

SecondPage.aspx.cs

using System;
using System.Data;
public partial class SecondPage : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        DataSet ds=(DataSet)Cache["Data"];
        GridView1.DataSource = ds;
        GridView1.DataBind();
    }
}

Adding Items to the Cache
Insert() method is used to add items to the cache. Insert() method have several overloaded method. Insert method can accept following parameters in different version of overloaded method.

    Key: It specifies the name of the new item.
    Value: It specifies the value of the new item.
    Dependencies: It supports the file, key, or SQL dependency. You can apply any of dependencies at a time.
    absoluteExpiration: DataTime object is used to specify the time duration. It is used to specify an absolute expiration time for the cached data. After that data is removed automatically from the cache.
    slidingExpiration: DataSpan object is used to specify the time duration. It is used to specify a sliding expiration duration for the cached data.
    Priority: It is used to set the priority of the cached item. You can use any of the following value  AboveNormal, BelowNormal, Default, High, Low, Normal, and NotRemovable.

Adding Items with an Expiration Policy
You can add different data object in cache object. When the memory is going to full, the server will automatically remove the item from cache. You can also specify an expiration time when the item will remove from the cache.

We can add the object into the cache by using insert() method. The cache.insert() method has 4 overloaded methods.


There are two different ways to expire the cache on the basis of time.

1. Absolute Expiration
2. Sliding Expiration

Absolute Expiration: This policy is useful when you know that your data does not change frequently. As its name suggests, the data from the cache will be removed after specified time, irrespective of whether cached data is accessed from cache or not. In absolute expiration DataTime object is used to specify the time duration.

Example

string strData = "The string data to be cached";        
Cache.Insert("AbsoluteCacheKey", strData, null,
DateTime.Now.AddMinutes(1), System.Web.Caching.Cache.NoSlidingExpiration);

Sliding Expiration: It defines that how long the data should remain available in the cache after the data was last accessed. It keeps the most frequently accessed items in memory. In sliding expiration TimeSpan object is used to specify the time duration.

Example

Cache.Insert("SlidingExpiration", strData, null,
System.Web.Caching.Cache.NoAbsoluteExpiration, TimeSpan.FromMinutes(1));

In the above examples, we have used string data type for caching, but you can use DataSet, DataTable, ArrayList or other type of data.
We cannot use absolute expiration and sliding expiration policies simultaneously. If you try to do it, it will give you runtime error.

Cache dependency on files
Suppose that we have data in a file and this data is cached for some specified time duration. If you want that whenever the file data is modified, the cached data is automatically removed from the cache. For this to happen we need to provide a dependency on the file.
First we will add a XML file in our project and write data as given below.

<?xml version="1.0" encoding="utf-8" ?>
<EmployeeInfo>
     <Employee>
          <EmpID>1</EmpID>
          <Name>Raj</Name>
          <Address>Pune</Address>
     </Employee>
     <Employee>
          <EmpID>2</EmpID>
          <Name>Shiva</Name>
          <Address>USA</Address>
     </Employee>
     <Employee>
          <EmpID>3</EmpID>
          <Name>Digvijay</Name>
          <Address>NewYork</Address>
     </Employee>
</EmployeeInfo>

Now take a GridView, a button, and a label on the web page and write code for access the EmployeeInfo.xml file.

using System;
using System.Data;
using System.Web.Caching;
public partial class DepandencyDemo : System.Web.UI.Page
{    
    protected void Page_Load(object sender, EventArgs e)
    {         
    }    
    protected void btnGetEmp_Click(object sender, EventArgs e)
    {
        if (Cache["EmpData"] != null)
        {
            DataSet ds = (DataSet)Cache["EmpData"];
            GridView1.DataSource = ds;
            GridView1.DataBind();
            Label1.Text = ds.Tables[0].Rows.Count.ToString()+"  records are retrieved from cache";
        }
        else
        {
            DataSet ds = new DataSet();
            ds.ReadXml(MapPath("∼/EmployeeInfo.xml"));
            Cache.Insert("EmpData", ds, new CacheDependency(MapPath("∼/EmployeeInfo.xml")), DateTime.Now.AddMinutes(1) Cache.NoSlidingExpiration);
            GridView1.DataSource = ds;
            GridView1.DataBind();
            Label1.Text = ds.Tables[0].Rows.Count.ToString() + "  records are retrieved from EmployeeInfo.xml file";
        }
    }
}

"""



Ans="""





Wireless (Unguided Media) Transmission transmission and reception are achieved by means of an antenna directional
transmitting antenna puts out focused beam
transmitter and receiver must be aligned omnidirectional
signal spreads out in all directions
can be received by many antennas
Wireless Examples terrestrial microwave satellite microwave broadcast radio infrared 

"""



Ans="""
'''

Name.html
<html>
<body bgcolor="blue">
<form action="http://192.168.8.3:8080/servlet/Greeting " method="get">
<input type="text" name="uname">
<input type="Submit" value="Submit">
<input type="Reset" value="Reset"></form>
</body>
</html>

Servlet File
Greeting.java



import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;
public class Greeting extends HttpServlet
{
public void doGet(HttpServletRequest req,HttpServletResponse res) throws ServletException,IOException
{
String username=req.getParameter("uname");
PrintWriter out=res.getWriter();
res.setContentType("text/html");
out.println("Welcome"+username);
out.close();
}
} 

'''
"""



Ans="""



using System;
using System.Text;
using System.Xml;

namespace WritingXml
{
    class Program
    {
        static void Main(string[] args)
        {
            XmlWriter xmlWriter = XmlWriter.Create("test.xml");

            xmlWriter.WriteStartDocument();
            xmlWriter.WriteStartElement("users");

            xmlWriter.WriteStartElement("user");
            xmlWriter.WriteAttributeString("age", "42");
            xmlWriter.WriteString("John Doe");
            xmlWriter.WriteEndElement();

            xmlWriter.WriteStartElement("user");
            xmlWriter.WriteAttributeString("age", "39");
            xmlWriter.WriteString("Jane Doe");

            xmlWriter.WriteEndDocument();
            xmlWriter.Close();
        }
    }
}
        

"""



Ans='''"""
"""
def quicksort(x):
      if len(x) < 2:
          return x
      else:
          pivot = x[0]
          less = [i for i in x[1:] if i <= pivot]
          greater = [i for i in x[1:] if i > pivot]
          return quicksort(less) + [pivot] + quicksort(greater)

"""
'''



Ans="""

<form id="form1" runat="server">

   <table style="width: 66%;">
   
      <tr>
         <td class="style1" colspan="3" align="center">
         <asp:Label ID="lblmsg" 
            Text="President Election Form : Choose your president" 
            runat="server" />
         </td>
      </tr>

      <tr>
         <td class="style3">
            Candidate:
         </td>

         <td class="style2">
            <asp:DropDownList ID="ddlcandidate" runat="server"  style="width:239px">
               <asp:ListItem>Please Choose a Candidate</asp:ListItem>
               <asp:ListItem>M H Kabir</asp:ListItem>
               <asp:ListItem>Steve Taylor</asp:ListItem>
               <asp:ListItem>John Abraham</asp:ListItem>
               <asp:ListItem>Venus Williams</asp:ListItem>
            </asp:DropDownList>
         </td>

         <td>
            <asp:RequiredFieldValidator ID="rfvcandidate" 
               runat="server" ControlToValidate ="ddlcandidate"
               ErrorMessage="Please choose a candidate" 
               InitialValue="Please choose a candidate">
            </asp:RequiredFieldValidator>
         </td>
      </tr>

      <tr>
         <td class="style3">
            House:
         </td>

         <td class="style2">
            <asp:RadioButtonList ID="rblhouse" runat="server" RepeatLayout="Flow">
               <asp:ListItem>Red</asp:ListItem>
               <asp:ListItem>Blue</asp:ListItem>
               <asp:ListItem>Yellow</asp:ListItem>
               <asp:ListItem>Green</asp:ListItem>
            </asp:RadioButtonList>
         </td>

         <td>
            <asp:RequiredFieldValidator ID="rfvhouse" runat="server" 
               ControlToValidate="rblhouse" ErrorMessage="Enter your house name" >
            </asp:RequiredFieldValidator>
            <br />
         </td>
      </tr>

      <tr>
         <td class="style3">
            Class:
         </td>

         <td class="style2">
            <asp:TextBox ID="txtclass" runat="server"></asp:TextBox>
         </td>

         <td>
            <asp:RangeValidator ID="rvclass" 
               runat="server" ControlToValidate="txtclass" 
               ErrorMessage="Enter your class (6 - 12)" MaximumValue="12" 
               MinimumValue="6" Type="Integer">
            </asp:RangeValidator>
         </td>
      </tr>

      <tr>
         <td class="style3">
            Email:
         </td>

         <td class="style2">
            <asp:TextBox ID="txtemail" runat="server" style="width:250px">
            </asp:TextBox>
         </td>

         <td>
            <asp:RegularExpressionValidator ID="remail" runat="server" 
               ControlToValidate="txtemail" ErrorMessage="Enter your email" 
               ValidationExpression="\w+([-+.']\w+)*@\w+([-.]\w+)*\.\w+([-.]\w+)*">
            </asp:RegularExpressionValidator>
         </td>
      </tr>

      <tr>
         <td class="style3" align="center" colspan="3">
            <asp:Button ID="btnsubmit" runat="server" onclick="btnsubmit_Click" 
               style="text-align: center" Text="Submit" style="width:140px" />
         </td>
      </tr>
   </table>
   <asp:ValidationSummary ID="ValidationSummary1" runat="server" 
      DisplayMode ="BulletList" ShowSummary ="true" HeaderText="Errors:" />
</form>


"""



Ans="""

    <?xml version="1.0" encoding="utf-8"?>  
    <android.support.constraint.ConstraintLayout xmlns:android="http://schemas.android.com/apk/res/android"  
        xmlns:app="http://schemas.android.com/apk/res-auto"  
        xmlns:tools="http://schemas.android.com/tools"  
        android:layout_width="match_parent"  
        android:layout_height="match_parent"  
        tools:context="example.javatpoint.com.screenorientation.MainActivity">  
      
      
        <Button  
            android:id="@+id/button1"  
            android:layout_width="wrap_content"  
            android:layout_height="wrap_content"  
            android:layout_marginBottom="8dp"  
            android:layout_marginTop="112dp"  
            android:onClick="onClick"  
            android:text="Launch next activity"  
            app:layout_constraintBottom_toBottomOf="parent"  
            app:layout_constraintEnd_toEndOf="parent"  
            app:layout_constraintHorizontal_bias="0.612"  
            app:layout_constraintStart_toStartOf="parent"  
            app:layout_constraintTop_toBottomOf="@+id/editText1"  
            app:layout_constraintVertical_bias="0.613" />  
      
        <TextView  
            android:id="@+id/editText1"  
            android:layout_width="wrap_content"  
            android:layout_height="wrap_content"  
            android:layout_centerHorizontal="true"  
            android:layout_marginEnd="8dp"  
            android:layout_marginStart="8dp"  
            android:layout_marginTop="124dp"  
            android:ems="10"  
            android:textSize="22dp"  
            android:text="This activity is portrait orientation"  
            app:layout_constraintEnd_toEndOf="parent"  
            app:layout_constraintHorizontal_bias="0.502"  
            app:layout_constraintStart_toStartOf="parent"  
            app:layout_constraintTop_toTopOf="parent" />  
    </android.support.constraint.ConstraintLayout>  

Activity class
File: MainActivity.java

    package example.javatpoint.com.screenorientation;  
      
    import android.content.Intent;  
    import android.support.v7.app.AppCompatActivity;  
    import android.os.Bundle;  
    import android.view.View;  
    import android.widget.Button;  
      
    public class MainActivity extends AppCompatActivity {  
      
        Button button1;  
        @Override  
        protected void onCreate(Bundle savedInstanceState) {  
            super.onCreate(savedInstanceState);  
            setContentView(R.layout.activity_main);  
      
            button1=(Button)findViewById(R.id.button1);  
        }  
        public void onClick(View v) {  
            Intent intent = new Intent(MainActivity.this,SecondActivity.class);  
            startActivity(intent);  
        }  
    }  

activity_second.xml
File: activity_second.xml

    <?xml version="1.0" encoding="utf-8"?>  
    <android.support.constraint.ConstraintLayout xmlns:android="http://schemas.android.com/apk/res/android"  
        xmlns:app="http://schemas.android.com/apk/res-auto"  
        xmlns:tools="http://schemas.android.com/tools"  
        android:layout_width="match_parent"  
        android:layout_height="match_parent"  
        tools:context="example.javatpoint.com.screenorientation.SecondActivity">  
      
        <TextView  
            android:id="@+id/textView"  
            android:layout_width="wrap_content"  
            android:layout_height="wrap_content"  
            android:layout_marginEnd="8dp"  
            android:layout_marginStart="8dp"  
            android:layout_marginTop="180dp"  
            android:text="this is landscape orientation"  
            android:textSize="22dp"  
            app:layout_constraintEnd_toEndOf="parent"  
            app:layout_constraintHorizontal_bias="0.502"  
            app:layout_constraintStart_toStartOf="parent"  
            app:layout_constraintTop_toTopOf="parent" />  
    </android.support.constraint.ConstraintLayout>  

SecondActivity class
File: SecondActivity.java

    package example.javatpoint.com.screenorientation;  
      
    import android.support.v7.app.AppCompatActivity;  
    import android.os.Bundle;  
      
    public class SecondActivity extends AppCompatActivity {  
      
        @Override  
        protected void onCreate(Bundle savedInstanceState) {  
            super.onCreate(savedInstanceState);  
            setContentView(R.layout.activity_second);  
      
        }  
    }  

AndroidManifest.xml
File: AndroidManifest.xml

In AndroidManifest.xml file add the screenOrientation attribute in activity and provides its orientation. In this example, we provide "portrait" orientation for MainActivity and "landscape" for SecondActivity.

    <?xml version="1.0" encoding="utf-8"?>  
    <manifest xmlns:android="http://schemas.android.com/apk/res/android"  
        package="example.javatpoint.com.screenorientation">  
      
        <application  
            android:allowBackup="true"  
            android:icon="@mipmap/ic_launcher"  
            android:label="@string/app_name"  
            android:roundIcon="@mipmap/ic_launcher_round"  
            android:supportsRtl="true"  
            android:theme="@style/AppTheme">  
            <activity  
                android:name="example.javatpoint.com.screenorientation.MainActivity"  
                android:screenOrientation="portrait">  
                <intent-filter>  
                    <action android:name="android.intent.action.MAIN" />  
      
                    <category android:name="android.intent.category.LAUNCHER" />  
                </intent-filter>  
            </activity>  
            <activity android:name=".SecondActivity"  
                android:screenOrientation="landscape">  
            </activity>  
        </application>  
      
    </manifest>

"""



Ans="""
'''

-- phpMyAdmin SQL Dump
-- version 3.4.5
-- http://www.phpmyadmin.net
--
-- Host: localhost
-- Generation Time: Jul 19, 2016 at 07:40 PM
-- Server version: 5.5.16
-- PHP Version: 5.4.0beta2-dev

SET SQL_MODE="NO_AUTO_VALUE_ON_ZERO";
SET time_zone = "+00:00";


/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;

--
-- Database: `test`
--

-- --------------------------------------------------------

--
-- Table structure for table `issuebooks`
--

CREATE TABLE IF NOT EXISTS `issuebooks` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `bookcallno` varchar(50) NOT NULL,
  `studentid` int(11) NOT NULL,
  `studentname` varchar(50) NOT NULL,
  `studentcontact` varchar(20) NOT NULL,
  `issueddate` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 AUTO_INCREMENT=8 ;

--
-- Dumping data for table `issuebooks`
--

INSERT INTO `issuebooks` (`id`, `bookcallno`, `studentid`, `studentname`, `studentcontact`, `issueddate`) VALUES
(4, 'A@4', 23, 'kk', '932992932', '2016-07-19 18:43:16'),
(6, 'A@4', 335, 'Sumedh', '95676565756', '2016-07-19 18:44:34'),
(7, 'A@4', 87, 'abhishek', '9329882382', '2016-07-19 18:46:12');

/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;

'''
"""



Ans="""

Aim: Study of different types of Network cables and Practically implement the cross-wired 
cable and straight through cable using clamping tool. 
Apparatus (Components): RJ-45 connector, Climping Tool, Twisted pair Cable 
Procedure: To do these practical following steps should be done: 
1. Start by stripping off about 2 inches of the plastic jacket off the end of the cable. Be very 
careful at this point, as to not nick or cut into the wires, which are inside. Doing so could alter 
the characteristics of your cable, or even worse render is useless. Check the wires, one more 
time for nicks or cuts. If there are any, just whack the whole end off, and start over. 
2. Spread the wires apart, but be sure to hold onto the base of the jacket with your other hand. 
You do not want the wires to become untwisted down inside the jacket. Category 5 cable 
must only have 1/2 of an inch of 'untwisted' wire at the end; otherwise it will be 'out of spec'. 
At this point, you obviously have ALOT more than 1/2 of an inch of un-twisted wire. 
3. You have 2 end jacks, which must be installed on your cable. If you are using a pre-made 
cable, with one of the ends whacked off, you only have one end to install - the crossed over 
end. Below are two diagrams, which show how you need to arrange the cables for each type 
of cable end.

RJ45(END 1)
Wh/Or
Or
Wh/Gr
Bl
Wh/Bl
Gr
Wh/Br
Br
RJ45(END 1)
Wh/Gr
Gr
Wh/Or
Wh/Br
Br
Or
Bl
Wh/Bl


"""



Ans="""
'''

import java.awt.BorderLayout;
import java.awt.EventQueue;

import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.border.EmptyBorder;
import javax.swing.GroupLayout;
import javax.swing.GroupLayout.Alignment;
import javax.swing.JLabel;
import java.awt.Font;
import java.awt.Color;
import javax.swing.JButton;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

public class LibrarianSuccess extends JFrame {
	static LibrarianSuccess frame;
	private JPanel contentPane;

	/**
	 * Launch the application.
	 */
	public static void main(String[] args) {
		EventQueue.invokeLater(new Runnable() {
			public void run() {
				try {
					frame = new LibrarianSuccess();
					frame.setVisible(true);
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		});
	}

	/**
	 * Create the frame.
	 */
	public LibrarianSuccess() {
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		setBounds(100, 100, 450, 433);
		contentPane = new JPanel();
		contentPane.setForeground(Color.GRAY);
		contentPane.setBorder(new EmptyBorder(5, 5, 5, 5));
		setContentPane(contentPane);
		
		JLabel lblLibrarianSection = new JLabel("Librarian Section - JavaTpoint");
		lblLibrarianSection.setFont(new Font("Tahoma", Font.PLAIN, 22));
		
		JButton btnNewButton = new JButton("Add Books");
		btnNewButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
			BooksForm.main(new String[]{});
			frame.dispose();
			}
		});
		btnNewButton.setFont(new Font("Tahoma", Font.PLAIN, 13));
		
		JButton btnViewBooks = new JButton("View Books");
		btnViewBooks.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent arg0) {
				ViewBooks.main(new String[]{});
			}
		});
		btnViewBooks.setFont(new Font("Tahoma", Font.PLAIN, 13));
		
		JButton btnIssueBook = new JButton("Issue Book");
		btnIssueBook.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				IssueBookForm.main(new String[]{});
				frame.dispose();
			}
		});
		btnIssueBook.setFont(new Font("Tahoma", Font.PLAIN, 13));
		
		JButton btnViewIssuedBooks = new JButton("View Issued Books");
		btnViewIssuedBooks.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				ViewIssuedBooks.main(new String[]{});
			}
		});
		btnViewIssuedBooks.setFont(new Font("Tahoma", Font.PLAIN, 13));
		
		JButton btnReturnBook = new JButton("Return Book");
		btnReturnBook.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				ReturnBook.main(new String[]{});
				frame.dispose();
			}
		});
		btnReturnBook.setFont(new Font("Tahoma", Font.PLAIN, 13));
		
		JButton btnLogout = new JButton("Logout");
		btnLogout.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				Library.main(new String[]{});
				frame.dispose();
			}
		});
		btnLogout.setFont(new Font("Tahoma", Font.PLAIN, 13));
		GroupLayout gl_contentPane = new GroupLayout(contentPane);
		gl_contentPane.setHorizontalGroup(
			gl_contentPane.createParallelGroup(Alignment.LEADING)
				.addGroup(Alignment.TRAILING, gl_contentPane.createSequentialGroup()
					.addContainerGap(81, Short.MAX_VALUE)
					.addComponent(lblLibrarianSection)
					.addGap(54))
				.addGroup(gl_contentPane.createSequentialGroup()
					.addGap(132)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.LEADING)
						.addComponent(btnLogout, GroupLayout.PREFERRED_SIZE, 191, GroupLayout.PREFERRED_SIZE)
						.addComponent(btnReturnBook, GroupLayout.PREFERRED_SIZE, 191, GroupLayout.PREFERRED_SIZE)
						.addComponent(btnViewIssuedBooks, GroupLayout.PREFERRED_SIZE, 191, GroupLayout.PREFERRED_SIZE)
						.addComponent(btnIssueBook, GroupLayout.PREFERRED_SIZE, 191, GroupLayout.PREFERRED_SIZE)
						.addComponent(btnViewBooks, GroupLayout.PREFERRED_SIZE, 191, GroupLayout.PREFERRED_SIZE)
						.addComponent(btnNewButton, GroupLayout.PREFERRED_SIZE, 191, GroupLayout.PREFERRED_SIZE))
					.addContainerGap(101, Short.MAX_VALUE))
		);
		gl_contentPane.setVerticalGroup(
			gl_contentPane.createParallelGroup(Alignment.LEADING)
				.addGroup(gl_contentPane.createSequentialGroup()
					.addContainerGap()
					.addComponent(lblLibrarianSection)
					.addGap(18)
					.addComponent(btnNewButton, GroupLayout.PREFERRED_SIZE, 37, GroupLayout.PREFERRED_SIZE)
					.addGap(18)
					.addComponent(btnViewBooks, GroupLayout.PREFERRED_SIZE, 37, GroupLayout.PREFERRED_SIZE)
					.addGap(18)
					.addComponent(btnIssueBook, GroupLayout.PREFERRED_SIZE, 37, GroupLayout.PREFERRED_SIZE)
					.addGap(18)
					.addComponent(btnViewIssuedBooks, GroupLayout.PREFERRED_SIZE, 37, GroupLayout.PREFERRED_SIZE)
					.addGap(18)
					.addComponent(btnReturnBook, GroupLayout.PREFERRED_SIZE, 37, GroupLayout.PREFERRED_SIZE)
					.addGap(18)
					.addComponent(btnLogout, GroupLayout.PREFERRED_SIZE, 37, GroupLayout.PREFERRED_SIZE)
					.addContainerGap(16, Short.MAX_VALUE))
		);
		contentPane.setLayout(gl_contentPane);
	}

}
'''
"""



Ans='''"""
from collections import defaultdict
 
#This class represents a directed graph using adjacency list representation
class Graph:
 
    def __init__(self,vertices):
        self.V= vertices #No. of vertices
        self.graph = defaultdict(list) # default dictionary to store graph
 
    # function to add an edge to graph
    def addEdge(self,u,v):
        self.graph[u].append(v)
     
     # Use BFS to check path between s and d
    def isReachable(self, s, d):
        # Mark all the vertices as not visited
        visited =[False]*(self.V)
 
        # Create a queue for BFS
        queue=[]
 
        # Mark the source node as visited and enqueue it
        queue.append(s)
        visited[s] = True
 
        while queue:

            #Dequeue a vertex from queue 
            n = queue.pop(0)
            
            # If this adjacent node is the destination node,
            # then return true
             if n == d:
                 return True

            #  Else, continue to do BFS
            for i in self.graph[n]:
                if visited[i] == False:
                    queue.append(i)
                    visited[i] = True
         # If BFS is complete without visited d
         return False
 
# Create a graph given in the above diagram
g = Graph(4)
g.addEdge(0, 1)
g.addEdge(0, 2)
g.addEdge(1, 2)
g.addEdge(2, 0)
g.addEdge(2, 3)
g.addEdge(3, 3)

u =1; v = 3

if g.isReachable(u, v):
    print("There is a path from %d to %d" % (u,v))
else :
    print("There is no path from %d to %d" % (u,v))

u = 3; v = 1
if g.isReachable(u, v) :
    print("There is a path from %d to %d" % (u,v))
else :
    print("There is no path from %d to %d" % (u,v))
"""
'''



Ans="""
'''

Index.html

<!DOCTYPE html>
<html>
<head>
<meta charset="ISO-8859-1">
<title> Insert title here </title>
</head>
<body>
<h1> Add New Employee </h1>
<form action="SaveServlet" method="post">
<table>
<tr><td>Name:</td><td><input type="password" name="password"/></td></tr> 
<tr><td>Password:</td><td><input type="password" name="password"/></td></tr> 
<tr><td>Email:</td><td><input type="email" name="email"/></td></tr>
<tr><td>Country:</td><td>
<select name="country" style="width:150px">
<option>India</option>
<option>USA</option>
<option>UK</option>
<option>Other</option>
</select>
</td></tr>
<tr><td colspan="2"><input type="submit" value="Save Employee"/></td></tr>
</table>
</form>
<br/>
<a href="ViewServlet">view employees</a>
</body>
</html>

Emp.java

public class Emp
{
private int id;
private String name,password,email,country;
public int getId()
{
return id;
}
public void setId(int id)
{
this.id=id;
}
public String getName()
{
return name;
}
public void setName(String name)
{
this.name=name;
}
public String getPassword()
{
return password;
}
public void setPassword(String password)
{
this.password=passwrord;
}
public string getEmail
{
return email;
}
public void setEmail(String email)
{
this.email=email;
}
public String getCountry()
{
return country;
}
public void setCountry(String country)
{
this.country=country;
}
}

EmpDao.java

import java.util.*;
import java.sql.*;
public class EmpDao
{
public static Connection getConnection()
{
Connection con = null;
try
{
Class.forName("oracle.jdbc.driver.OracleDriver");
con = DriverManager.getConnection("jdbc:oracle:thin:@localhost:1521:xe","system","oracle");
}
catch(Exception e)
{
System.out.println(e);
}
return con;
}
public static int save(Emp e)
{
int status=0;
try{
Connection con = EmpDao.getConnection();
PreparedStatement ps = con.prepareStatement("insert into Employee(name,password,email,country)values(?,?,?,?)");
ps.setString(1,e.getName());
ps.setString(2,e.getPassword());
ps.setString(3,e.getEmail());
ps.setString(4,e.getCountry());

status = ps.executeUpdate();
con.close();
}
catch(Exception ex)
{
return status;
}
public static int update(Emp e)
{
int status=0;
try
{
Connection con = EmpDao.getConnection();
PreparedStatement ps = con.prepareStatement("update Employee set name=?,password=?,email=?,country=? where id=?");
ps.setString(1,e.getName());
ps.setString(2,e.getPassword());
ps.setString(3,e.getEmail());
ps.setString(4,e.getCountry());
ps.setInt(5,e.getId());

status = ps.executeUpdate();
con.close();
}
catch(Exception ex)
{
ex.printStackTrace();
}
return status;
}
public static int delete(int id)
{
int status=0;
try
{
Connection con = EmpDao.getConnection();
PreparedStatement ps = con.prepareStatement("update Employee set name=?,password=?,email=?,country=? where id=?");

ps.setInt(1,id);

status = ps.executeUpdate();
con.close();
}
catch(Exception ex)
{
ex.printStackTrace();
}
return status;
}
public static Emp getEmployeeById(int id)
{
Emp e = new Emp();
try
{
Connection con = EmpDao.getConnection();
PreparedStatement ps = con.prepareStatement("select * from Employee where id=?");
ps.setInt(1,id);
ResultSet rs = ps.executeQuery();
if(rs.next())
{
e.setId(rs.getInt(1));
e.setName(rs.getString(2));
e.setPassword(rs.getString(3));
e.setEmail(rs.getString(4));
e.setCountry(rs.getString(5));
}
con.close();
}
catch(Exception ex)
{
ex.printStackTrace();
}
return e;
}
public static List<Emp> getAllEmployees()
{
List<Emp> list = new ArrayList<Emp>();
try
{
Connection con = EmpDao.getConnection();
PreparedStatement ps = con.prepareStatement("select * from Employee");
ResultSet rs = ps.executeQuery();
while(rs.next())
{
Emp e = new Emp();
e.setId(rs.getInt(1));
e.setName(rs.getString(2));
e.setPassword(rs.getString(3));
e.setEmail(rs.getString(4));
e.setCountry(rs.getString(5));
list.add(e);
}
con.close();
}
catch(Exception e)
{
e.printStackTrace();
}
return list;
}
}

SaveServlet.java

import java.io.IOException;
import java.io.PrintWriter;
import javax.servlet.ServletException;
import javax.servlet.anotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
@WebServlet("/SaveServlet")
public class SaveServlet2 extends HttpServlet
{
protected void doPost(HttpServletRequest request,HttpServletResponse response)throws ServletException,IOException
{
response.setContentType("text/html");
PrintWriter out=response.getWriter();

String name=request.getParameter("name");
String password=request.getParameter("password");
String email=request.getParameter("email"); 
String country=request.getParameter("country"); 

Emp e=new Emp();
e.setName(name);
e.setPassword(password);
e.setEmail(email);
e.setCountry(country);

int status=EmpDao.save(e);
if(status>0)
{
out.print("<p>Record saved successfully!<p>");
request.getRequestDispatcher("index.html").include(request,response);
}
else
{
out.println("Sorry! unable to save record");
}
out.close();
}
}

EditServlet.java

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
@WebServlet("/EditServlet2")
public class EditServlet2 extends HttpServlet
{
protected void doPost(HttpServletRequest request,HttpServletResponse response)throws ServletException,IOException
{
response.setContentType("text/html");
PrintWriter out=response.getWriter();
out.print("<h1>Update Employee<h1>");
String sid=request.getParameter("id");
int id=Integer.parseInt(sid);

Emp e = EmpDao.getEmployeeById(id);
out.print("<form action='EditServlet2' method='post'>");
out.print("<table>");
out.print("<tr><td></td><td><input type='hidden' name='id' value='"+e.getId()+"'/></td></tr>");
out.print("<tr><td>Name:</td><td><input type='text' name='name' value='"+e.getName()+"'/></td></tr>");
out.print("<tr><td>Password:</td><td><input type='password' name='password' value='"+e.getPassword()+"'/></td></tr>");
out.print("<tr><td>Email:</td><td><input type='email' name='email' value='"+e.getEmail()+"'/></td></tr>");
out.print("<tr><td>Country:</td><td>");
out.print("<select name='country' style='width:150px'>");
out.print("<option>India</option>");
out.print("<option>USA</option>");
out.print("<option>UK</option>");
out.print("<option>Other</option>");
out.print("</select>");
out.print("</td></tr>");
out.print("<tr><td colspan='2'><input type='submit' value='Edit & Save'/></td></tr>");
out.print("</table>");
out.print("</form>");
out.close();
}
}

EditServlet2.java

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
@WebServlet("/EditServlet2")
public class EditServlet2 extends HttpServlet
{
protected void doPost(HttpServletRequest request,HttpServletResponse response)throws ServletException,IOException
{
response.setContentType("text/html");
PrintWriter out=response.getWriter();
String sid=request.getParameter("id");
int id=Integer.parseInt(sid);
String name=request.getParameter("name");
String password=request.getParameter("password");
String email=request.getParameter("email"); 
String country=request.getParameter("country"); 
Emp e=new Emp();
e.setId(id);
e.setName(name);
e.setPassword(password);
e.setEmail(email);
e.setCountry(country);

int status=EmpDao.update(e);
if(status>0)
{
response.sendRedirect("ViewServlet");
}
else
{
out.println("Sorry! unable to update record");
}

out.close();
}
}

DeleteServlet.java

import java.io.IOException;
import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
@WebServlet("/DeleteServlet2")
public class DeleteServlet2 extends HttpServlet
{
protected void doGet(HttpServletRequest request,HttpServletResponse response)throws ServletException,IOException
{
String sid=request.getParameter("id");
int id=Integer.parseInt(sid);
EmpDao.delete(id);
response.sendRedirect("ViewServlet");
}
}

ViewServlet.java

import java.io.IOException;
import java.io.PrintWriter;
import java.util.List;
import javax.servlet.ServletException;
importjavax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
@WebServlet("/ViewServlet")
public classViewServlet extends HttpServlet
{
protected void doGet(HttpServletRequest request,HttpServletResponse response)throws ServletException, IOException
{
response.setContentType("text/html");
PrintWriter out=response.getWriter();
out.println("<a href='index.html>Add New Employee</a>");
out.println("<h1>Employees List</h1>");
List<Emp> list=EmpDao.getAllEmployees();

out.print("<table border='1' width='100%'");
out.print("<tr><th>Id</th><th>Nmae</th><th>Password</th><th>Email</th><th>Country</th><th>Edit</th><th>Delete</th></tr>");
for(Emp e:list)
{
out.print("<tr><td>"+e.getId()+"</td><td>"+e.getName()+"</td><td>"+e.getPassword()+"</td><td>"+e.getEmail()+"</td><td>"+e.getCountry()+"</td>
<td><a href='EditServlet?id="+e.getId()+'">edit</a></td>
<td><a href='DeleteServlet?id="+e.getId()+'">delete</a></td></tr>");
}
out.print("</table>");
out.close();
}
}


'''
"""



Ans="""

1. What web server software issued by www.snopes.com?Analysis –
The domain name be found from host header so we will set host header column where we will see all domain name.
Select any HTTP request and expand the Hypertext Transfer Protocol then right click on Host header and then Apply as Column
Now we can see our host www.snopes.com in host column.Right click on the selected packet and then select Follow TCP stream.
Now we can see the webserver name in server header it is Microsoft IIS 5.0

2.  About what cell phone problem is the client concerned?
Analysis – Client talking about cell so we search for cell keyword in whole packets.
We will use regular express for searching the cell keyword.
Apply frame matches “(?!) cell”
After applying the filter now, we will start to check every HTTP request.
We noticed in the first HTTP request cell keyword is in URL and it was about cell phone charging issue.

3. According to Zillow, what instrument will Ryan learn to play?
Analysis – As we did in the last challenge, we will apply a regular express filter for the Zillow keyword.
Apply frame matched “(?!) zillow”
After applying the filter, we found only one packet with the Zillow keyword
Select the packet and expand the Hypertext Transfer Protocol
tab right click on it go to Protocol Preferences and check Allow subdissector to resemble TCP stream
Now go to file and select Export Objects > HTTP. It will save all objects from the packet.
Click on Save all
After saving all files in a directory and we found a swf file with name Zillow.
After opening the flash file, we saw that Zillow was trying to learn saxophone.
Answer is saxophone but file is swf so cant play

4.  How many web servers are running Apache?
Analysis – The web server name can be retrieved from HTTP response header.
So will apply filter http. response and we can see all http response packets
Now we will set the server header as column select any packet and right click on it then select Apply as Column
Now can see the server column where all server name is showing.
Now we have to check how many Apache packets are there we can’t count manually for each packet
so we will apply another filter http.server contains “Apache”
After applying filter go to Statistics > Endpoints
It will show all connections
Check the limit to display filter then it will show the actual Apache connections. Now there are showing 22 connections
but will exclude 192.168.1.71 because it is client’s IP not a server IP so there are actual 21 Apache servers.


"""



Ans="""

import numpy as np
m=np.array([1,1,2],[2,6,7],[3,6,7])
print(m)
for i in range(0,3):
    print("Row"+str(i))
a=5
print(a*m)
print(m.transpose())
def iden(n):
    for i in range(0,n):
        for j in range(0,n):
            if(i==j):
                print("1",sep=" ",end=" ")
            else:
                print("0",sep=" ",end=" ")
        print()
iden(4)
def matsym(m,n):
    for i in range(0,n):
        for j in range(0,n):
            if m[i][j]!=m[j][i]:
                return False
    return True
matsym(m)

"""



Ans='''"""
class Node(object):
    def __init__(self, data):
        self.data = data
        self.leftChild = None
        self.rightChild = None

    def insert(self, data):
        ''' For inserting the data in the Tree '''
        if self.data == data:
            return False        # As BST cannot contain duplicate data

        elif data < self.data:
            ''' Data less than the root data is placed to the left of the root '''
            if self.leftChild:
                return self.leftChild.insert(data)
            else:
                self.leftChild = Node(data)
                return True

        else:
            ''' Data greater than the root data is placed to the right of the root '''
            if self.rightChild:
                return self.rightChild.insert(data)
            else:
                self.rightChild = Node(data)
                return True

    def minValueNode(self, node):
        current = node

        # loop down to find the leftmost leaf
        while(current.leftChild is not None):
            current = current.leftChild

        return current

    def delete(self, data):
        ''' For deleting the node '''
        if self is None:
            return None

        # if current node's data is less than that of root node, then only search in left subtree else right subtree
        if data < self.data:
            self.leftChild = self.leftChild.delete(data)
        elif data > self.data:
            self.rightChild = self.rightChild.delete(data)
        else:
            # deleting node with one child
            if self.leftChild is None:
                temp = self.rightChild
                self = None
                return temp
            elif self.rightChild is None:
                temp = self.leftChild
                self = None
                return temp

            # deleting node with two children
            # first get the inorder successor
            temp = self.minValueNode(self.rightChild)
            self.data = temp.data
            self.rightChild = self.rightChild.delete(temp.data)

        return self

    def find(self, data):
        ''' This function checks whether the specified data is in tree or not '''
        if(data == self.data):
            return True
        elif(data < self.data):
            if self.leftChild:
                return self.leftChild.find(data)
            else:
                return False
        else:
            if self.rightChild:
                return self.rightChild.find(data)
            else:
                return False

    def preorder(self):
        '''For preorder traversal of the BST '''
        if self:
            print(str(self.data), end = ' ')
            if self.leftChild:
                self.leftChild.preorder()
            if self.rightChild:
                self.rightChild.preorder()

    def inorder(self):
        ''' For Inorder traversal of the BST '''
        if self:
            if self.leftChild:
                self.leftChild.inorder()
            print(str(self.data), end = ' ')
            if self.rightChild:
                self.rightChild.inorder()

    def postorder(self):
        ''' For postorder traversal of the BST '''
        if self:
            if self.leftChild:
                self.leftChild.postorder()
            if self.rightChild:
                self.rightChild.postorder()
            print(str(self.data), end = ' ')

class Tree(object):
    def __init__(self):
        self.root = None

    def insert(self, data):
        if self.root:
            return self.root.insert(data)
        else:
            self.root = Node(data)
            return True

    def delete(self, data):
        if self.root is not None:
            return self.root.delete(data)

    def find(self, data):
        if self.root:
            return self.root.find(data)
        else:
            return False

    def preorder(self):
        if self.root is not None:
            print()
            print('Preorder: ')
            self.root.preorder()

    def inorder(self):
        print()
        if self.root is not None:
            print('Inorder: ')
            self.root.inorder()

    def postorder(self):
        print()
        if self.root is not None:
            print('Postorder: ')
            self.root.postorder()

if __name__ == '__main__':
    tree = Tree()
    tree.insert(10)
    tree.insert(12)
    tree.insert(5)
    tree.insert(4)
    tree.insert(20)
    tree.insert(8)
    tree.insert(7)
    tree.insert(15)
    tree.insert(13)
    print(tree.find(1))
    print(tree.find(12))
     Following tree is getting created:
                    10
                 /      \
               5         12
              / \           \
            4     8          20
                 /          /
                7         15
                         /
                       13
    

    tree.preorder()
    tree.inorder()
    tree.postorder()
    print('\n\nAfter deleting 20')
    tree.delete(20)
    tree.inorder()
    tree.preorder()
    print('\n\nAfter deleting 10')
    tree.delete(10)
    tree.inorder()
    tree.preorder()
"""
'''



Ans="""

    <?xml version="1.0" encoding="utf-8"?>  
    <android.support.constraint.ConstraintLayout xmlns:android="http://schemas.android.com/apk/res/android"  
        xmlns:app="http://schemas.android.com/apk/res-auto"  
        xmlns:tools="http://schemas.android.com/tools"  
        android:layout_width="match_parent"  
        android:layout_height="match_parent"  
        tools:context="example.javatpoint.com.togglebutton.MainActivity">  
      
        <ToggleButton  
            android:id="@+id/toggleButton"  
            android:layout_width="wrap_content"  
            android:layout_height="wrap_content"  
            android:layout_marginLeft="8dp"  
            android:layout_marginTop="80dp"  
            android:text="ToggleButton"  
            android:textOff="Off"  
            android:textOn="On"  
            app:layout_constraintEnd_toStartOf="@+id/toggleButton2"  
            app:layout_constraintStart_toStartOf="parent"  
            app:layout_constraintTop_toTopOf="parent" />  
      
        <ToggleButton  
            android:id="@+id/toggleButton2"  
            android:layout_width="wrap_content"  
            android:layout_height="wrap_content"  
            android:layout_marginRight="60dp"  
            android:layout_marginTop="80dp"  
            android:text="ToggleButton"  
            android:textOff="Off"  
            android:textOn="On"  
            app:layout_constraintEnd_toEndOf="parent"  
            app:layout_constraintTop_toTopOf="parent" />  
      
        <Button  
            android:id="@+id/button"  
            android:layout_width="wrap_content"  
            android:layout_height="wrap_content"  
            android:layout_marginBottom="144dp"  
            android:layout_marginLeft="148dp"  
            android:text="Submit"  
            app:layout_constraintBottom_toBottomOf="parent"  
            app:layout_constraintStart_toStartOf="parent" />  
    </android.support.constraint.ConstraintLayout>  

Activity class

Let's write the code to check which toggle button is ON/OFF.
File: MainActivity.java

    package example.javatpoint.com.togglebutton;  
      
    import android.support.v7.app.AppCompatActivity;  
    import android.os.Bundle;  
    import android.view.View;  
    import android.widget.Button;  
    import android.widget.Toast;  
    import android.widget.ToggleButton;  
      
    public class MainActivity extends AppCompatActivity {  
        private ToggleButton toggleButton1, toggleButton2;  
        private Button buttonSubmit;  
        @Override  
        protected void onCreate(Bundle savedInstanceState) {  
            super.onCreate(savedInstanceState);  
            setContentView(R.layout.activity_main);  
      
            addListenerOnButtonClick();  
        }  
      
        public void addListenerOnButtonClick(){  
            //Getting the ToggleButton and Button instance from the layout xml file  
            toggleButton1=(ToggleButton)findViewById(R.id.toggleButton);  
            toggleButton2=(ToggleButton)findViewById(R.id.toggleButton2);  
            buttonSubmit=(Button)findViewById(R.id.button);  
      
            //Performing action on button click  
            buttonSubmit.setOnClickListener(new View.OnClickListener(){  
      
                @Override  
                public void onClick(View view) {  
                    StringBuilder result = new StringBuilder();  
                    result.append("ToggleButton1 : ").append(toggleButton1.getText());  
                    result.append("\nToggleButton2 : ").append(toggleButton2.getText());  
                    //Displaying the message in toast  
                    Toast.makeText(getApplicationContext(), result.toString(),Toast.LENGTH_LONG).show();  
                }  
      
            });  
      
        }  
    }
    
"""



Ans="""
'''

Follow the steps:
1.Download the jar from here-
https://code.google.com/archive/p/json-simple/downloads.
2.Gotonetbeans- in your “Projects” window go for- “libraries” right click on it and “json-simple-1.1.1” folder to it.
3.Write encoding code:

import java.util.HashMap;
import java.util.Map;
import org.json.simple.JSONValue;

public class JSON_USING_MAP
{
public static void main(String args[])
{
Map obj = new HashMap()
System.out.println("Encoding Using MAP....\n");

obj.put("COLLEGE NAME","ABC COLLEGE");
obj.put("YEAR OF ESTD",new Integer(1927));
obj.put("NO OF COURSES",new Double(60));

String txt = JSONValue.to.JSONString(obj);
System.out.print(txt);
}
}
4.This will generate certain output.
Encoding….
{“NO OF COURSES”:60.0,”YEAR OF ESTD”:1927,”COLLEGE NAME”:”XYZ COLLEGE”}
 
5.We can also obtain same results using MAP.

import org.json.simple.JSONObject;
public class JSON_ENCODE_DECODE
{
public static void main(String[] args)
{
JSONObject obj = new JSONObject();
System.out.println("Encoding.....\n");

obj.put("COLLEGE NAME","ABC COLLEGE");
obj.put("YEAR OF ESTD",new Integer(1927));
obj.put("NO OF COURSES",new Double(60));

System.out.print(obj);
}
}

6.This will also generate certain output.
Encoding Using MAP…..
{“NO OF COURSES”:60.0,”YEAR OF ESTD”:1927,”COLLEGE NAME”:”XYZ COLLEGE”}

7.Let’s see how to decode…

import org.json.simple.JSONObject;
import org.json.simple.JSONValue;

public class JSON_DECODE
{
public static void main(String[] args)
{
String s="{\"COLLEGE NAME\":\"XYZ COLLEGE\",\"YEAR OF ESTD\":1987.0,\"NO OF COURSES\":56}";
Object obj = JSONValue.parse(s);

JSONObject Obj = (JSONObject) obj;

String col_name = (String)jsObj.get("COLLEGE NAME");
double year = (Double)jsObj.get("YEAR OF ESTD");
long courses = (Long)jsObj.get("NO OF COURSES");
System.out.println(col_name+"\n"+year+"\n"+courses);
}
}

8.This will generate following output:
XYZ COLLEGE
1987.0
56 

'''
"""



Ans="""
'''

index.jsp

<%@ page language="java" contentType="text/html; charset=ISO-8859-1"
    pageEncoding="ISO-8859-1"%>
<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1">
<title>Check Box Test</title>
</head>
<body>
<form action="checkBoxData" method="post">
<table>
<tr>
<td>
<input type="checkbox" name="hobbies" value="Singing">Singing
</td>
</tr>
<tr>
<td>
<input type="checkbox" name="hobbies" value="Dancing">Dancing
</td>
</tr>
<tr>
<td>
<input type="checkbox" name="hobbies" value="Painting">Painting
</td>
</tr> 
<tr>
<td>
<input type="submit" value="Send">
</td>
</tr>
</table>
</form>
</body>
</html>

CheckBoxDemoServlet.java

package CheckBoxDemo;

import java.io.IOException;
import java.io.PrintWriter;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

public class CheckBoxDemoServlet extends HttpServlet {
    private static final long serialVersionUID = 1L;
    protected void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        doPost(request,response);
    }
    protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
    try
    {
     String hobbise[] = request.getParameterValues("hobbies") ;
     
     PrintWriter writer =  response.getWriter();
     response.setContentType("text/html");
     writer.println("<h2><font color=green>Your Hobbies :</font></h2>");
     
     for(String value : hobbise)
     {
     writer.println("<br><font color=blue>"+value+"</font>");
     }  
     
     writer.close();
    }
    catch(Exception exception)
    {
        exception.printStackTrace();    
    }
    }
}

web.xml

 <?xml version="1.0" encoding="UTF-8"?>
<web-app xmlns:web="http://java.sun.com/xml/ns/javaee/web-app_2_5.xsd">
  <servlet>
    <servlet-name>checkBoxServlet</servlet-name>
    <servlet-class>CheckBoxDemo.CheckBoxDemoServlet</servlet-class>
  </servlet>
  <servlet-mapping>
    <servlet-name>checkBoxServlet</servlet-name>
    <url-pattern>/checkBoxData</url-pattern>
  </servlet-mapping>
  <welcome-file-list>
    <welcome-file>index.jsp</welcome-file>
  </welcome-file-list>
</web-app>

'''
"""



Ans="""

Step 1 − Create a new project in Android Studio, go to File ⇒ New Project and fill all required details to create a new project.

Step 2 − Add the following code to res/layout/activity_main.xml.

<?xml version="1.0" encoding="utf-8"?>
<LinearLayout xmlns:android="http://schemas.android.com/apk/res/android"
   android:layout_width="match_parent"
   android:id="@+id/layout"
   android:gravity="center"
   android:layout_height="match_parent"
   android:orientation="vertical">
   <TextView
      android:id="@+id/counttime"
      android:layout_width="match_parent"
      android:gravity="center"
      android:textSize="30sp"
      android:layout_height="wrap_content" />
</LinearLayout>

In the above code, we have declared a text view. it going to print countdown timer.

Step 3 − Add the following code to src/MainActivity.java

package com.example.andy.myapplication;
import android.annotation.TargetApi;
import android.os.Build;
import android.os.Bundle;
import android.os.CountDownTimer;
import android.support.v7.app.AppCompatActivity;
import android.view.View;
import android.widget.Button;
import android.widget.RatingBar;
import android.widget.TextView;
import android.widget.Toast;
public class MainActivity extends AppCompatActivity {
   public int counter;
   @TargetApi(Build.VERSION_CODES.O)
   @Override
   protected void onCreate(Bundle savedInstanceState) {
      super.onCreate(savedInstanceState);
      setContentView(R.layout.activity_main);
      final TextView counttime=findViewById(R.id.counttime);
      new CountDownTimer(50000,1000) {
         @Override
         public void onTick(long millisUntilFinished) {
            counttime.setText(String.valueOf(counter));
            counter++;
         }
         @Override
         public void onFinish() {
            counttime.setText("Finished");
         }
      }.start();
   }
}
    
"""



Ans="""
'''

import java.io.IOException;
import java.io.PrintWriter;
import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

public class ServletLifeCycle extends HttpServlet
{
public ServletLifeCycle()
{
System.out.println(“Am from default constructor”);
}
public void init(ServletConfig config)
{
System.out.println(“Am from Init method…!”);
}
public void doGet(HttpServletReuest req, HttpServletResponse res)throws ServletException, IOException
{
 res.setContentType(“text/html”);
PrintWriter pw =  res.getWriter();
pw.println(“I am from doGet method”);
pw.close();
}
public void destroy()
{
System.out.println(“Am from Destroy methods”);
}
}


Web.xml

<web-app>
<servlet>
<servlet-name>second</servlet-name>
<servlet-class>java4s.ServletLifeCycle</servlet-class>
<load-on-startup>1</load-on-startup>
</servlet>

<servlet-mapping>
<servlet-name>second</servlet-name>
<url-pattern>/lifecycle1</url-pattern>
</servlet-mapping>
</web-app>


'''
"""



Ans="""
'''

import java.awt.BorderLayout;
import java.awt.EventQueue;

import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.border.EmptyBorder;
import javax.swing.GroupLayout;
import javax.swing.GroupLayout.Alignment;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JTextField;
import javax.swing.JButton;
import java.awt.Font;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

public class DeleteLibrarian extends JFrame {
	static DeleteLibrarian frame;
	private JPanel contentPane;
	private JTextField textField;

	/**
	 * Launch the application.
	 */
	public static void main(String[] args) {
		EventQueue.invokeLater(new Runnable() {
			public void run() {
				try {
					frame = new DeleteLibrarian();
					frame.setVisible(true);
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		});
	}

	/**
	 * Create the frame.
	 */
	public DeleteLibrarian() {
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		setBounds(100, 100, 450, 300);
		contentPane = new JPanel();
		contentPane.setBorder(new EmptyBorder(5, 5, 5, 5));
		setContentPane(contentPane);
		
		JLabel lblEnterId = new JLabel("Enter Id:");
		
		textField = new JTextField();
		textField.setColumns(10);
		
		JButton btnDelete = new JButton("Delete");
		btnDelete.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				String sid=textField.getText();
				if(sid==null||sid.trim().equals("")){
					JOptionPane.showMessageDialog(DeleteLibrarian.this,"Id can't be blank");
				}else{
					int id=Integer.parseInt(sid);
					int i=LibrarianDao.delete(id);
					if(i>0){
						JOptionPane.showMessageDialog(DeleteLibrarian.this,"Record deleted successfully!");
					}else{
						JOptionPane.showMessageDialog(DeleteLibrarian.this,"Unable to delete given id!");
					}
				}
			}
		});
		btnDelete.setFont(new Font("Tahoma", Font.PLAIN, 13));
		
		JButton btnNewButton = new JButton("Back");
		btnNewButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				AdminSuccess.main(new String[]{});
				frame.dispose();
			}
		});
		btnNewButton.setFont(new Font("Tahoma", Font.PLAIN, 13));
		GroupLayout gl_contentPane = new GroupLayout(contentPane);
		gl_contentPane.setHorizontalGroup(
			gl_contentPane.createParallelGroup(Alignment.LEADING)
				.addGroup(gl_contentPane.createSequentialGroup()
					.addGap(39)
					.addComponent(lblEnterId)
					.addGap(57)
					.addComponent(textField, GroupLayout.PREFERRED_SIZE, 178, GroupLayout.PREFERRED_SIZE)
					.addContainerGap(107, Short.MAX_VALUE))
				.addGroup(Alignment.TRAILING, gl_contentPane.createSequentialGroup()
					.addContainerGap(175, Short.MAX_VALUE)
					.addComponent(btnDelete, GroupLayout.PREFERRED_SIZE, 109, GroupLayout.PREFERRED_SIZE)
					.addGap(140))
				.addGroup(Alignment.TRAILING, gl_contentPane.createSequentialGroup()
					.addContainerGap(322, Short.MAX_VALUE)
					.addComponent(btnNewButton, GroupLayout.PREFERRED_SIZE, 92, GroupLayout.PREFERRED_SIZE)
					.addContainerGap())
		);
		gl_contentPane.setVerticalGroup(
			gl_contentPane.createParallelGroup(Alignment.LEADING)
				.addGroup(gl_contentPane.createSequentialGroup()
					.addGap(19)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.LEADING)
						.addComponent(textField, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE)
						.addComponent(lblEnterId))
					.addGap(33)
					.addComponent(btnDelete, GroupLayout.PREFERRED_SIZE, 33, GroupLayout.PREFERRED_SIZE)
					.addGap(43)
					.addComponent(btnNewButton)
					.addContainerGap(78, Short.MAX_VALUE))
		);
		contentPane.setLayout(gl_contentPane);
	}
}

'''
"""



Ans="""

package com.example.ListDisplay;

import android.os.Bundle;
import android.app.Activity;
import android.view.Menu;
import android.widget.ArrayAdapter;
import android.widget.ListView;

public class ListDisplay extends Activity {
   // Array of strings...
   String[] mobileArray = {"Android","IPhone","WindowsMobile","Blackberry",
      "WebOS","Ubuntu","Windows7","Max OS X"};
   
   @Override
   protected void onCreate(Bundle savedInstanceState) {
      super.onCreate(savedInstanceState);
      setContentView(R.layout.activity_main);
      
      ArrayAdapter adapter = new ArrayAdapter<String>(this, 
         R.layout.activity_listview, mobileArray);
      
      ListView listView = (ListView) findViewById(R.id.mobile_list);
      listView.setAdapter(adapter);
   }
}

Following will be the content of res/layout/activity_main.xml file −

<LinearLayout xmlns:android="http://schemas.android.com/apk/res/android"
   xmlns:tools="http://schemas.android.com/tools"
   android:layout_width="match_parent"
   android:layout_height="match_parent"
   android:orientation="vertical"
   tools:context=".ListActivity" >

   <ListView
      android:id="@+id/mobile_list"
      android:layout_width="match_parent"
      android:layout_height="wrap_content" >
   </ListView>
 
</LinearLayout>

Following will be the content of res/values/strings.xml to define two new constants −

<?xml version="1.0" encoding="utf-8"?>
<resources>
   <string name="app_name">ListDisplay</string>
   <string name="action_settings">Settings</string>
</resources>

Following will be the content of res/layout/activity_listview.xml file −

<?xml version="1.0" encoding="utf-8"?>
<!--  Single List Item Design -->

<TextView xmlns:android="http://schemas.android.com/apk/res/android"
   android:id="@+id/label"
   android:layout_width="fill_parent"
   android:layout_height="fill_parent"
   android:padding="10dip"
   android:textSize="16dip"
   android:textStyle="bold" >
</TextView>
    
"""



Ans="""

public class Methodoveloading    
  {    
    public int add(int a, int b)  //two int type Parameters method  
    {    
        return a + b;    
        
    }    
    public int add(int a, int b,int c)  //three int type Parameters with same method same as above  
    {    
        return a + b+c;    
    
    }    
    public float add(float a, float b,float c,float d)  //four float type Parameters with same method same as above two method 
    {    
        return a + b+c+d;    
    
    }    
  }

"""



Ans="""

    using System;  
       public class Animal  
        {  
           public void eat() { Console.WriteLine("Eating..."); }  
       }  
       public class Dog: Animal  
       {  
           public void bark() { Console.WriteLine("Barking..."); }  
       }  
       class TestInheritance2{  
           public static void Main(string[] args)  
            {  
                Dog d1 = new Dog();  
                d1.eat();  
                d1.bark();  
            }  
        }  

"""



Ans="""

'''
To do this, we find the values ofλwhich satisfy thecharacteristic equationof thematrixA, namely those values ofλfor whichdet(A−λI) = 0,whereIis the 3×3identity matrix
Once theeigenvaluesof a matrix (A) have been found, we can find theeigenvectorsby Gaussian Elimination.•STEP 1: For each eigenvalueλ, we have(A−λI)x=0,wherexis theeigenvectorassociated witheigenvalueλ.•STEP 2: Findxby Gaussian elimination. That is, convert the augmented matrix(A−λI...0)to row echelon form, and solve the resulting linear system byback substitution.We find theeigenvectorsassociated with each of theeigenvalues
row echeleon is upper triangular
'''

import numpy as np
m = np.mat("3 -2;1 0")
print("Original matrix:")
print("a\n", m)
w, v = np.linalg.eig(m) 
print( "Eigenvalues of the said matrix",w)
print( "Eigenvectors of the said matrix",v)

"""



Ans="""
'''
A matrix is in reduced row echelon form (also called row canonical form) if it satisfies the following conditions:[3]

    It is in row echelon form.
    The leading entry in each nonzero row is a 1 (called a leading 1).
    Each column containing a leading 1 has zeros everywhere else.

'''
def row_mult(row,num):
return[x*num for x in row]
#subtract one row from another
def row_sub(row_left,row_right):
return[a-b for (a,b) in zip(row_left,row_right)]
#row_echelon ::Matrix->Matrix
def row_echelon(mtx):
temp_mtx=list(mtx)
def echelonify(rw,col):
for i,row in enumerate(temp_mtx[(col+1):]):
i+=1
if rw[col]==0:continue
temp_mtx[i+col]=row_sub(row,row_mult(rw,row[col]/r
w[col]))
for i in range(len(mtx)):
active_row=temp_mtx[i]
echelonify(active_row,i)
#flatten out values very close to zero
temp_mtx=[
[(0 if(0.0000000001>x>-0.0000000001)else x)
for x in row]
for row in temp_mtx
]
return temp_mtx
#accept input of square matrix
print('enter dimensions of matrix')
r=int(input('enter no of rows'))
c=int(input('enter no of columns'))
mtx=[]
mtx_result=[]
for i in range(r):
mtx.append([])
print('enter elements of row',i)
for j in range(c):
n=float(input('enter element'))
mtx[i].append(n)
print('entered matrix')
for row in mtx:
print(''.join(("{0:.2f}".format(x)for x in row)))
mtx_result=row_echelon(mtx)
print('Row Echelon form matrix')
for row in mtx_result:
print(''.join(("{0:.2f}".format(x)for x in row)))


"""



Ans='''"""
"""
m1=[[1,2,3],
    [4,5,6],
    [7,8,9]]
m2=[[10,11,12,13],
    [14,15,16,17],
    [18,19,20,21]]
rmatrix=[[0,0,0,0],[0,0,0,0],[0,0,0,0]]
for i in range(len(m1)):
    for j in range(len(m2[0])):
        for k in range(len(m2)):
            rmatrix[i][j]+=m1[i][k]*m2[k][j]
for r in rmatrix:
    print(r)
"""
def matmul():
    print("Enter Details For Matrix 1")
    m1=[]
    nrow=int(input("Enter no of rows"))
    ncol=int(input("Enter no of columns"))
    for i in range(nrow):
        m1.insert(i,[])
        for j in range(ncol):
            temp=int(input("Enter Element["+str(i)+"]["+str(j)+"]"))
            m1[i].append(temp)
    print("Enter Details For Matrix 2")
    m2=[]
    nrow=int(input("Enter no of rows"))
    ncol=int(input("Enter no of columns"))
    for i in range(nrow):
        m2.insert(i,[])
        for j in range(ncol):
            temp=int(input("Enter Element["+str(i)+"]["+str(j)+"]"))
            m2[i].append(temp)
    nrow=len(m1)
    ncol=len(m2[0])
    l1=[]
    for i in range(nrow):
        l1.append([])
        for j in range(ncol):
            l1[i].append(0)
    for i in range(len(m1)):
        for j in range(len(m2[0])):
            for k in range(len(m2)):
                l1[i][j]+=m1[i][k]*m2[k][j]
    for i in l1:
        print(i)
matmul()
"""
'''



Ans="""

'''

Orthogonal projection is a cornerstone of vector space methods, with many diverse applications. These include, but are not limited to, Least squares projection, also known as linear regression. Conditional expectations for multivariate normal (Gaussian) distributions.
'''

import numpy as np 
  
# vector u  
u = np.array([2, 5, 8])        
  
# vector n: n is orthogonal vector to Plane P 
n = np.array([1, 1, 7])        
   
# Task: Project vector u on Plane P 
  
# finding norm of the vector n  
n_norm = np.sqrt(sum(n**2))     
   
# Apply the formula as mentioned above 
# for projecting a vector onto the orthogonal vector n 
# find dot product using np.dot() 
proj_of_u_on_n = (np.dot(u, n)/n_norm**2)*n 
  
# subtract proj_of_u_on_n from u:  
# this is the projection of u on Plane P 
print("Projection of Vector u on Plane P is: ", u - proj_of_u_on_n)

"""



Ans="""
'''

import java.sql.Connection;
import java.sql.PreparedStatement;

public class BookDao {
public static int save(String callno,String name,String author,String publisher,int quantity){
	int status=0;
	try{
		Connection con=DB.getConnection();
		PreparedStatement ps=con.prepareStatement("insert into books(callno,name,author,publisher,quantity) values(?,?,?,?,?)");
		ps.setString(1,callno);
		ps.setString(2,name);
		ps.setString(3,author);
		ps.setString(4,publisher);
		ps.setInt(5,quantity);
		status=ps.executeUpdate();
		con.close();
	}catch(Exception e){System.out.println(e);}
	return status;
}
}

'''
"""



Ans="""
'''

Index.jsp

<!DOCTYPE html>
<html>
<head>
<meta http-euiv="Content-Type" content="text/html";charset=ISO-8859-1">
<title>JSP CRUD Example</title>
</head>
<body>
<h1>JSP CRUD Example</h1>
<a href="adduserform.jsp">Add User</a>
<a href="viewuser.jsp">View Users</a>
</body>
</html>

Adduserform.jsp

<!DOCTYPE html>
<html>
<head>
<meta http-euiv="Content-Type" content="text/html";charset=ISO-8859-1">
<title>JSP CRUD Example</title>
</head>
<body>

<jsp:include page="userform.html"></jsp:include>
</body>
</html>
Userform.html
0<a href="viewusers.jsp">View All Records</a><br/>
<h1>Add New User</h1>
<form action="adduser.jsp" method="post">
<table>
<tr><td>Name:</td><td><input type="text" name="name"/></td></tr>
<tr><td>Password:</td><td><input type="password" name="password"/></td></tr>
<tr><td>Email:</td><td><input type='"email" name="email"/></td></tr>
<tr><td>Sex:</td><td>
<input type="radio" name="sex" value"male"/>Male
<input type="radio" name="sex" value"female"/>Female</td></tr>
<tr><td>Country:</td><td>
<select name='country' style='width:150px'>
<option>India</option>
<option>Pakistan</option>
<option>Afghanistan</option>
<option>Berma</option>
<option>Other</option>
</select>
</td></tr>
<tr><td colspan='2'><input type="submit" value="Add User"/></td></tr>
</table>
</form>

Adduser.jsp

<%@page import="com.javapoint.dao.UserDao"%>
<jsp:useBean id="u" class="com.javapoint.bean.User"></jsp:useBean>
<jsp:setProperty property="*" name="u"/>

<%
int i=UserDao.save(u);
if(i>0)
{
response.sendRedirect("adduser-success.jsp");
}
else
{
response.sendRedirect("adduser-error.jsp");
}
%>

User.java

package com.javapoint.bean;
public class User
{
private int id;
private String name,password,emai,sex,country;
}

UserDao.java

package com.javapoint.dao;
import java.sql.*;
import java.util.ArrayList;
import java.util.List;
import com.javapoint.bean.User;
public class UserDao
{
public static Connection getConnection()
{
Connection con=null;
try
{
Class.forName("com.mysql.jdbc.Driver");
con=DriverManager.getConnection("jdbc:mysql://localhost:3306/test","","");
}
catch(Exception e)
{
System.out.println(e);
}
return con;
}

public static int save(User u)
{
int status=0;
try
{
Connection con = getConnection();
PreparedStatement ps = con.prepareStatement("insert into register(name,password,email,sex,country) values(?,?,?,?,?)");
ps.setString(1,u.getName()); 
ps.setString(2,u.getPassword());
ps.setString(3,u.getEmail());
ps.setString(4,u.getSex());
ps.setString(5,u.getCountry()); 
status=ps.executeUpdate();
}
catch(Exception e)
{
System.out.println(e);
}
return status;
}
public static int update(User u)
{
int status=0;
try
{
Connection con = getConnection();
PreparedStatement ps = con.prepareStatement("update register set name=?,password=?,email=?,sex=?,country=? where id =?");
ps.setString(1,u.getName()); 
ps.setString(2,u.getPassword());
ps.setString(3,u.getEmail());
ps.setString(4,u.getSex());
ps.setString(5,u.getCountry());
ps.setInt(6,u.getId()); 
status=ps.executeUpdate();
}
catch(Exception e)
{
System.out.println(e);
}
return status;
}
public static int delete(User u)
{
int status=0;
try
{
Connection con = getConnection();
PreparedStatement ps = con.prepareStatement("insert into register(name,password,email,sex,country) values(?,?,?,?,?)");
ps.setInt(6,u.getId()); 
status=ps.executeUpdate();
}
catch(Exception e)
{
System.out.println(e);
}
return status;
}

public static List<User> getAllRecords()
{
List<User> list = new ArayList<User>();
try
{
Connection con = getConnection();
PreparedStatement ps = con.prepareStatement("select * from register");
ResultSet rs = ps.executeQuery();
while(rs.next())
{
User u = new User();
u.setId(rs.getInt("id"));
u.setName(rs.getString("name"));
u.setPassword(rs.getString("password"));
u.setEmail(rs.getString("email"));
u.setSex(rs.getString("sex"));
u.setCountry(rs.getString("country"));
list.add(u);
}
catch(Exception e)
{
System.out.println(e);
}
return list;
}
public static User getRecordById(int id)
{
User u = null;
try
{
Connection con = getConnection();
PreparedStatement ps = con.prepareStatement("select * from register where id=?");
ps.setInt(1,id);
ResultSet rs = ps.executeQuery();
while(rs.next())
{
u = new User();
u.setId(rs.getInt("id"));
u.setName(rs.getString("name"));
u.setPassword(rs.getString("password"));
u.setEmail(rs.getString("email"));
u.setSex(rs.getString("sex"));
u.setCountry(rs.getString("country"));
}
catch(Exception e)
{
System.out.println(e);
}
return u;
}
}

Adduser-success.jsp

<!DOCTYPE html>
<html>
<head>
<meta http-euiv="Content-Type" content="text/html";charset=ISO-8859-1">
<title>Add User Success</title>
</head>
<body>
<p> Record successfully saved!</p>
<jsp:include page="userform.html"></jsp:include>
</body>
</html>

Adduser-error.jsp

<!DOCTYPE html>
<html>
<head>
<meta http-euiv="Content-Type" content="text/html";charset=ISO-8859-1">
<title>Add User Error</title>
</head>
<body>
<p>Sorry, an error occurred!</p>
<jsp:include page="userform.html"></jsp:include>
</body>
</html>

Viewusers.jsp

<!DOCTYPE html>
<html>
<head>
<meta http-euiv="Content-Type" content="text/html";charset=ISO-8859-1">
<title>View Users</title>
</head>
<body>
<%@page import="com.javapoint.dao.Userdao,com.javapoint.bean.*.java.util.*"%>
<%@taglib uri="http://java.sun.com/jsp/jstl/core" prefix="c"%>

<h1>Users List</h1>
<%
List<User> list=UserDao.getAllRecords();
request.setAttribute("list",list);
%>

<table border="1" width="90%">
<tr><th>Id</th><th>Name</th><th>Password</th><th>Email</th><th>Sex</th><th>Country</th><th>Edit</th><th>Delete</th></tr>
<c:forEach items="${list}" var="u">
<tr><td>${u.getId()}</td><td>${u.getName()}</td><td>${u.getPassword()}</td><td>${u.getEmail()}</td><td>${u.getSex()}</td><td>${u.getCountry()}</td>
<td><a href="editform.jsp?id=$u.getId()}">Edit</a></td> 
<td><a href="deleteuser.jsp?id=$u.getId()}">Delete</a></td></tr>
</c:forEach>
</table>
<br/><a href="adduserform.jsp">Add New User</a>
</body>
</html>

Editform.jsp

<!DOCTYPE html>
<html>
<head>
<meta http-euiv="Content-Type" content="text/html";charset=ISO-8859-1">
<title>Edit Form</title>
</head>
<body>
<%@page import="com.javapoint.dao.Userdao,com.javapoint.bean.*.java.util.*"%>

<%
String id=request.getParamater("id");
User u=UserDao.getRecordById(Intege.parseInt(id));
%>
<h1>Edit Form</h1>
<form action="edituser.jsp" method="post">
<input type="hidden" name="id" value="<%=u.getId()%>"/>
<table>
<tr><td>Name:</td><td><input type="text" name="name" value="<%=u.getName()%>/></td></tr>
<tr><td>Password:</td><td><input type="password" name="password"value="<%=u.getPassword()%>/></td></tr>
<tr><td>Email:</td><td><input type='"email" name="email" value="<%=u.getEmail()%>/></td></tr>
<tr><td>Sex:</td><td>
<input type="radio" name="sex" value"male"/>Male
<input type="radio" name="sex" value"female"/>Female</td></tr>
<tr><td>Country:</td><td>
<select name='country' style='width:150px'>
<option>India</option>
<option>Pakistan</option>
<option>Afghanistan</option>
<option>Berma</option>
<option>Other</option>
</select>
</td></tr>
<tr><td colspan='2'><input type="submit" value="Add User"/></td></tr>
</table>
</form>
</body>
</html>

Edituser.jsp
<%@page import="com.javapoint.dao.UserDao"%>
<jsp:useBean id="u" class="com.javapoint.bean.User"></jsp:useBean>
<jsp:setProperty property="*" name="u"/>
<%
int i=UserDao.save(u);
response.sendRedirect("viewusrs.jsp");
%>

Deleteuser.jsp

<%@page import="com.javapoint.dao.UserDao"%>
<jsp:useBean id="u" class="com.javapoint.bean.User"></jsp:useBean>
<jsp:setProperty property="*" name="u"/>

<%
UserDao.delete(u);
response.sendRedirect("viewusers.jsp");
%>


'''
"""



Ans="""
'''

-- phpMyAdmin SQL Dump
-- version 3.4.5
-- http://www.phpmyadmin.net
--
-- Host: localhost
-- Generation Time: Jul 19, 2016 at 07:40 PM
-- Server version: 5.5.16
-- PHP Version: 5.4.0beta2-dev

SET SQL_MODE="NO_AUTO_VALUE_ON_ZERO";
SET time_zone = "+00:00";


/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;

--
-- Database: `test`
--

-- --------------------------------------------------------

--
-- Table structure for table `books`
--

CREATE TABLE IF NOT EXISTS `books` (
  `id` int(10) NOT NULL AUTO_INCREMENT,
  `callno` varchar(100) NOT NULL,
  `name` varchar(100) NOT NULL,
  `author` varchar(100) NOT NULL,
  `publisher` varchar(100) NOT NULL,
  `quantity` int(10) NOT NULL,
  `issued` int(10) NOT NULL,
  `added_date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  UNIQUE KEY `callno` (`callno`),
  UNIQUE KEY `callno_2` (`callno`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 AUTO_INCREMENT=4 ;

--
-- Dumping data for table `books`
--

INSERT INTO `books` (`id`, `callno`, `name`, `author`, `publisher`, `quantity`, `issued`, `added_date`) VALUES
(1, 'A@4', 'C In Depth', 'Shrivastav', 'BPB', 2, 2, '2016-07-19 19:37:56'),
(2, 'B@1', 'DBMS', 'Korth', 'Pearson', 3, 0, '2016-07-18 18:39:52'),
(3, 'G@12', 'Let''s see', 'Yashwant Kanetkar', 'BPB', 10, 0, '2016-07-18 23:02:14');

/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;

'''
"""



Ans='''"""

def insertion_sort(integers):
    """Iterate over the list of integers. With each iteration,
    place the new element into its sorted position by shifting
    over elements to the left of the pointer until the correct
    location is found for the new element.
    Sorts the list in place. O(n^2) running time, O(1) space. 
    """
    integers_clone = list(integers)
    for i in range(1, len(integers_clone)):
        j = i
        while integers_clone[j] < integers_clone[j - 1] and j > 0:
            integers_clone[j], integers_clone[j-1] = integers_clone[j-1], integers_clone[j]
            j -= 1
            
    return integers_clone

"""
'''



Ans="""
'''

import java.awt.BorderLayout;
import java.awt.EventQueue;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;

import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.border.EmptyBorder;
import javax.swing.JTable;

public class ViewIssuedBooks extends JFrame {

	private JPanel contentPane;
	private JTable table;

	public static void main(String[] args) {
		EventQueue.invokeLater(new Runnable() {
			public void run() {
				try {
					ViewIssuedBooks frame = new ViewIssuedBooks();
					frame.setVisible(true);
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		});
	}

	/**
	 * Create the frame.
	 */
	public ViewIssuedBooks() {
		setDefaultCloseOperation(JFrame.HIDE_ON_CLOSE);
		setBounds(100, 100, 450, 300);
		contentPane = new JPanel();
		contentPane.setBorder(new EmptyBorder(5, 5, 5, 5));
		contentPane.setLayout(new BorderLayout(0, 0));
		setContentPane(contentPane);
		
		String data[][]=null;
		String column[]=null;
		try{
			Connection con=DB.getConnection();
			PreparedStatement ps=con.prepareStatement("select * from issuebooks",ResultSet.TYPE_SCROLL_SENSITIVE,ResultSet.CONCUR_UPDATABLE);
			ResultSet rs=ps.executeQuery();
			
			ResultSetMetaData rsmd=rs.getMetaData();
			int cols=rsmd.getColumnCount();
			column=new String[cols];
			for(int i=1;i<=cols;i++){
				column[i-1]=rsmd.getColumnName(i);
			}
			
			rs.last();
			int rows=rs.getRow();
			rs.beforeFirst();

			data=new String[rows][cols];
			int count=0;
			while(rs.next()){
				for(int i=1;i<=cols;i++){
					data[count][i-1]=rs.getString(i);
				}
				count++;
			}
			con.close();
		}catch(Exception e){System.out.println(e);}
		
		table = new JTable(data,column);
		JScrollPane sp=new JScrollPane(table);
		
		contentPane.add(sp, BorderLayout.CENTER);
	}

}
'''
"""



Ans="""

activity_main.xml

File: activity_main.xml

    <?xml version="1.0" encoding="utf-8"?>  
    <LinearLayout  
        xmlns:android="http://schemas.android.com/apk/res/android"  
        xmlns:tools="http://schemas.android.com/tools"  
        android:layout_width="match_parent"  
        android:layout_height="match_parent"  
        android:orientation="vertical"  
        tools:context="example.javatpoint.com.radiobutton.MainActivity">  
      
        <TextView  
            android:id="@+id/textView1"  
            android:layout_width="fill_parent"  
            android:layout_height="wrap_content"  
            android:layout_marginTop="30dp"  
            android:gravity="center_horizontal"  
            android:textSize="22dp"  
            android:text="Single Radio Buttons" />  
      
      
      
        <!--   Default RadioButtons  -->  
      
        <RadioButton  
            android:id="@+id/radioButton1"  
            android:layout_width="fill_parent"  
            android:layout_height="wrap_content"  
            android:layout_gravity="center_horizontal"  
            android:text="Radio Button 1"  
            android:layout_marginTop="20dp"  
      
            android:textSize="20dp" />  
        <RadioButton  
            android:id="@+id/radioButton2"  
            android:layout_width="fill_parent"  
            android:layout_height="wrap_content"  
            android:text="Radio Button 2"  
            android:layout_marginTop="10dp"  
      
            android:textSize="20dp" />  
      
      
        <View  
            android:layout_width="fill_parent"  
            android:layout_height="1dp"  
            android:layout_marginTop="20dp"  
            android:background="#B8B894" />  
      
        <TextView  
            android:id="@+id/textView2"  
            android:layout_width="fill_parent"  
            android:layout_height="wrap_content"  
            android:layout_marginTop="30dp"  
            android:gravity="center_horizontal"  
            android:textSize="22dp"  
            android:text="Radio button inside RadioGroup" />  
      
      
        <!--   Customized RadioButtons  -->  
      
      
        <RadioGroup  
            android:layout_width="wrap_content"  
            android:layout_height="wrap_content"  
            android:id="@+id/radioGroup">  
      
            <RadioButton  
                android:id="@+id/radioMale"  
                android:layout_width="fill_parent"  
                android:layout_height="wrap_content"  
                android:text="  Male"  
                android:layout_marginTop="10dp"  
                android:checked="false"  
                android:textSize="20dp" />  
      
            <RadioButton  
                android:id="@+id/radioFemale"  
                android:layout_width="fill_parent"  
                android:layout_height="wrap_content"  
                android:text="   Female"  
                android:layout_marginTop="20dp"  
                android:checked="false"  
      
                android:textSize="20dp" />  
        </RadioGroup>  
      
        <Button  
            android:layout_width="wrap_content"  
            android:layout_height="wrap_content"  
            android:text="Show Selected"  
            android:id="@+id/button"  
            android:onClick="onclickbuttonMethod"  
            android:layout_gravity="center_horizontal" />  
      
      
    </LinearLayout>  

Activity class

File: MainActivity.java

    package example.javatpoint.com.radiobutton;  
      
    import android.support.v7.app.AppCompatActivity;  
    import android.os.Bundle;  
    import android.view.View;  
    import android.widget.Button;  
    import android.widget.RadioButton;  
    import android.widget.RadioGroup;  
    import android.widget.Toast;  
      
    public class MainActivity extends AppCompatActivity {  
        Button button;  
        RadioButton genderradioButton;  
        RadioGroup radioGroup;  
        @Override  
        protected void onCreate(Bundle savedInstanceState) {  
            super.onCreate(savedInstanceState);  
            setContentView(R.layout.activity_main);  
            radioGroup=(RadioGroup)findViewById(R.id.radioGroup);  
        }  
        public void onclickbuttonMethod(View v){  
            int selectedId = radioGroup.getCheckedRadioButtonId();  
            genderradioButton = (RadioButton) findViewById(selectedId);  
            if(selectedId==-1){  
                Toast.makeText(MainActivity.this,"Nothing selected", Toast.LENGTH_SHORT).show();  
            }  
            else{  
                Toast.makeText(MainActivity.this,genderradioButton.getText(), Toast.LENGTH_SHORT).show();  
            }  
      
        }  
    }  
"""



Ans="""

import matplotlib.pyplot as plt
x=2+4j
scale=0.5
scale1=0.33
scale2=2
plt.scatter(x.real,x.imag,color='red')
c=scale*x
d=scale1*x
e=scale2*x
plt.scatter(c.real,c.imag,color='green')
plt.scatter(d.real,d.imag,color='blue')
plt.scatter(e.real,e.imag,color='black')


"""



Ans="""

    <?xml version="1.0" encoding="utf-8"?>  
    <android.support.constraint.ConstraintLayout xmlns:android="http://schemas.android.com/apk/res/android"  
        xmlns:app="http://schemas.android.com/apk/res-auto"  
        xmlns:tools="http://schemas.android.com/tools"  
        android:layout_width="match_parent"  
        android:layout_height="match_parent"  
        tools:context="example.javatpoint.com.checkbox.MainActivity">  
      
      
        <CheckBox  
            android:id="@+id/checkBox"  
            android:layout_width="wrap_content"  
            android:layout_height="wrap_content"  
            android:layout_marginLeft="144dp"  
            android:layout_marginTop="68dp"  
            android:text="Pizza"  
            app:layout_constraintStart_toStartOf="parent"  
            app:layout_constraintTop_toTopOf="parent" />  
      
        <CheckBox  
            android:id="@+id/checkBox2"  
            android:layout_width="wrap_content"  
            android:layout_height="wrap_content"  
            android:layout_marginLeft="144dp"  
            android:layout_marginTop="28dp"  
            android:text="Coffee"  
            app:layout_constraintStart_toStartOf="parent"  
            app:layout_constraintTop_toBottomOf="@+id/checkBox" />  
      
        <CheckBox  
            android:id="@+id/checkBox3"  
            android:layout_width="wrap_content"  
            android:layout_height="wrap_content"  
            android:layout_marginLeft="144dp"  
            android:layout_marginTop="28dp"  
            android:text="Burger"  
            app:layout_constraintStart_toStartOf="parent"  
            app:layout_constraintTop_toBottomOf="@+id/checkBox2" />  
      
        <Button  
            android:id="@+id/button"  
            android:layout_width="wrap_content"  
            android:layout_height="wrap_content"  
            android:layout_marginLeft="144dp"  
            android:layout_marginTop="184dp"  
            android:text="Order"  
            app:layout_constraintStart_toStartOf="parent"  
            app:layout_constraintTop_toBottomOf="@+id/checkBox3" />  
      
    </android.support.constraint.ConstraintLayout>  

Activity class

Let's write the code to check which toggle button is ON/OFF.
File: MainActivity.java

    package example.javatpoint.com.checkbox;  
      
    import android.support.v7.app.AppCompatActivity;  
    import android.os.Bundle;  
    import android.view.View;  
    import android.widget.Button;  
    import android.widget.CheckBox;  
    import android.widget.Toast;  
      
    public class MainActivity extends AppCompatActivity {  
        CheckBox pizza,coffe,burger;  
        Button buttonOrder;  
        @Override  
        protected void onCreate(Bundle savedInstanceState) {  
            super.onCreate(savedInstanceState);  
            setContentView(R.layout.activity_main);  
            addListenerOnButtonClick();  
        }  
        public void addListenerOnButtonClick(){  
            //Getting instance of CheckBoxes and Button from the activty_main.xml file  
            pizza=(CheckBox)findViewById(R.id.checkBox);  
            coffe=(CheckBox)findViewById(R.id.checkBox2);  
            burger=(CheckBox)findViewById(R.id.checkBox3);  
            buttonOrder=(Button)findViewById(R.id.button);  
      
            //Applying the Listener on the Button click  
            buttonOrder.setOnClickListener(new View.OnClickListener(){  
      
                @Override  
                public void onClick(View view) {  
                    int totalamount=0;  
                    StringBuilder result=new StringBuilder();  
                    result.append("Selected Items:");  
                    if(pizza.isChecked()){  
                        result.append("\nPizza 100Rs");  
                        totalamount+=100;  
                    }  
                    if(coffe.isChecked()){  
                        result.append("\nCoffe 50Rs");  
                        totalamount+=50;  
                    }  
                    if(burger.isChecked()){  
                        result.append("\nBurger 120Rs");  
                        totalamount+=120;  
                    }  
                    result.append("\nTotal: "+totalamount+"Rs");  
                    //Displaying the message on the toast  
                    Toast.makeText(getApplicationContext(), result.toString(), Toast.LENGTH_LONG).show();  
                }  
      
            });  
        }  
    }

    
"""



Ans='''"""
"""tournament method A method of finding a specific element in some set (e.g. largest of a set of numbers), so called because it involves pairing elements and comparing them to find which one goes through to the next stage, leaving just one element at the end that has not lost."""

def largest(L):
    global paris
    if len(L) == 1:
        return L[0]
    else:
        left = largest(L[:len(L)//2])
        right = largest(L[len(L)//2:])
        pairs.append((left, right))
        return max(left, right)

def second_largest(L):
    global pairs
    biggest = largest(L)
    second_L = [min(item) for item in pairs if biggest in item]

    return biggest, largest(second_L)  



if __name__ == "__main__":
    pairs = []
    # test array
    L = [2,-2,10,5,4,3,1,2,90,-98,53,45,23,56,432]    

    if len(L) == 0:
        first, second = None, None
    elif len(L) == 1:
        first, second = L[0], None
    else:
        first, second = second_largest(L)

    print('The largest number is: ' + str(first))
    print('The 2nd largest number is: ' + str(second))


"""
'''



Ans="""
from PIL import Image
import numpy as np
a=Image.open('D:\sy16\linear alg\image1')
b=Image.open('D:\sy16\linear alg\image2')
l1=np.array(a)
l2=np.array(b)
def imresize(im,sz):
        PIL_im=Image.fromarray(np.unit8(im))
        return np.array(PIL_im.resize(sz))
r1=imresize(l1,(200,200))
r2=imresize(l2,(200,200))
a1=Image.fromarray(r1)
b1=Image.fromarray(r2)
a1.show()
b1.show()


"""



Ans="""

protected void Page_Load(object sender, EventArgs e)
    {

    }
    protected void btnclear_Click(object sender, EventArgs e)
    {
        ViewState["name"] = txtname.Text;
        txtname.Text = "";
    }
    protected void btndisplay_Click(object sender, EventArgs e)
    {
        lbl.Text = ViewState["name"].ToString();
    }
        

"""



Ans="""
'''

import java.awt.BorderLayout;
import java.awt.EventQueue;

import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.border.EmptyBorder;
import javax.swing.GroupLayout;
import javax.swing.GroupLayout.Alignment;
import javax.swing.JLabel;
import javax.swing.JOptionPane;

import java.awt.Font;
import java.awt.Color;
import javax.swing.JTextField;
import javax.swing.JButton;
import javax.swing.LayoutStyle.ComponentPlacement;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

public class ReturnBook extends JFrame {
	static ReturnBook frame;
	private JPanel contentPane;
	private JTextField textField;
	private JTextField textField_1;

	/**
	 * Launch the application.
	 */
	public static void main(String[] args) {
		EventQueue.invokeLater(new Runnable() {
			public void run() {
				try {
					frame = new ReturnBook();
					frame.setVisible(true);
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		});
	}

	/**
	 * Create the frame.
	 */
	public ReturnBook() {
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		setBounds(100, 100, 516, 413);
		contentPane = new JPanel();
		contentPane.setBorder(new EmptyBorder(5, 5, 5, 5));
		setContentPane(contentPane);
		
		JLabel lblReturnBook = new JLabel("Return Book");
		lblReturnBook.setForeground(Color.GRAY);
		lblReturnBook.setFont(new Font("Tahoma", Font.PLAIN, 18));
		
		JLabel lblBookCallno = new JLabel("Book Callno:");
		
		JLabel lblStudentId = new JLabel("Student Id:");
		
		textField = new JTextField();
		textField.setColumns(10);
		
		textField_1 = new JTextField();
		textField_1.setColumns(10);
		
		JButton btnReturnBook = new JButton("Return Book");
		btnReturnBook.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				String bookcallno=textField.getText();
				int studentid=Integer.parseInt(textField_1.getText());
				int i=ReturnBookDao.delete(bookcallno, studentid);
				if(i>0){
					JOptionPane.showMessageDialog(ReturnBook.this,"Book returned successfully!");
					LibrarianSuccess.main(new String[]{});
					frame.dispose();
					
				}else{
					JOptionPane.showMessageDialog(ReturnBook.this,"Sorry, unable to return book!");
				}
			}
		});
		
		JLabel lblNewLabel = new JLabel("Note: Check the book properly!");
		lblNewLabel.setForeground(Color.RED);
		lblNewLabel.setFont(new Font("Tahoma", Font.PLAIN, 13));
		
		JButton btnBack = new JButton("Back");
		btnBack.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				LibrarianSuccess.main(new String[]{});
				frame.dispose();
			}
		});
		GroupLayout gl_contentPane = new GroupLayout(contentPane);
		gl_contentPane.setHorizontalGroup(
			gl_contentPane.createParallelGroup(Alignment.TRAILING)
				.addGroup(gl_contentPane.createSequentialGroup()
					.addGap(36)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.TRAILING, false)
						.addComponent(lblStudentId, Alignment.LEADING, GroupLayout.DEFAULT_SIZE, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
						.addComponent(lblBookCallno, Alignment.LEADING, GroupLayout.DEFAULT_SIZE, 78, Short.MAX_VALUE))
					.addGap(56)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.LEADING)
						.addComponent(textField_1, GroupLayout.PREFERRED_SIZE, 181, GroupLayout.PREFERRED_SIZE)
						.addComponent(textField, GroupLayout.PREFERRED_SIZE, 181, GroupLayout.PREFERRED_SIZE))
					.addContainerGap(139, Short.MAX_VALUE))
				.addGroup(gl_contentPane.createSequentialGroup()
					.addContainerGap(210, Short.MAX_VALUE)
					.addComponent(btnReturnBook, GroupLayout.PREFERRED_SIZE, 104, GroupLayout.PREFERRED_SIZE)
					.addGap(176))
				.addGroup(gl_contentPane.createSequentialGroup()
					.addContainerGap(205, Short.MAX_VALUE)
					.addComponent(lblReturnBook)
					.addGap(187))
				.addGroup(gl_contentPane.createSequentialGroup()
					.addGap(19)
					.addComponent(lblNewLabel)
					.addContainerGap(294, Short.MAX_VALUE))
				.addGroup(gl_contentPane.createSequentialGroup()
					.addContainerGap(355, Short.MAX_VALUE)
					.addComponent(btnBack)
					.addGap(46))
		);
		gl_contentPane.setVerticalGroup(
			gl_contentPane.createParallelGroup(Alignment.LEADING)
				.addGroup(gl_contentPane.createSequentialGroup()
					.addContainerGap()
					.addComponent(lblReturnBook)
					.addGap(32)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.BASELINE)
						.addComponent(lblBookCallno)
						.addComponent(textField, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
					.addGap(34)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.BASELINE)
						.addComponent(lblStudentId)
						.addComponent(textField_1, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
					.addGap(29)
					.addComponent(btnReturnBook, GroupLayout.PREFERRED_SIZE, 34, GroupLayout.PREFERRED_SIZE)
					.addGap(23)
					.addComponent(btnBack)
					.addPreferredGap(ComponentPlacement.RELATED, 28, Short.MAX_VALUE)
					.addComponent(lblNewLabel)
					.addGap(72))
		);
		contentPane.setLayout(gl_contentPane);
	}

}
'''
"""



Ans='''"""
import queue

class HuffmanNode(object):
    def __init__(self,left=None,right=None,root=None):
        self.left = left
        self.right = right
        self.root = root
    def children(self):
        return (self.left,self.right)
    def preorder(self,path=None):
        if path is None:
            path = []
        if self.left is not None:
            if isinstance(self.left[1], HuffmanNode):
                self.left[1].preorder(path+[0])
            else:
                print(self.left,path+[0])
        if self.right is not None:
            if isinstance(self.right[1], HuffmanNode):
                self.right[1].preorder(path+[1])
            else:
                print(self.right,path+[1])

freq = [
    (8.167, 'a'), (1.492, 'b'), (2.782, 'c'), (4.253, 'd'),
    (12.702, 'e'),(2.228, 'f'), (2.015, 'g'), (6.094, 'h'),
    (6.966, 'i'), (0.153, 'j'), (0.747, 'k'), (4.025, 'l'),
    (2.406, 'm'), (6.749, 'n'), (7.507, 'o'), (1.929, 'p'),
    (0.095, 'q'), (5.987, 'r'), (6.327, 's'), (9.056, 't'),
    (2.758, 'u'), (1.037, 'v'), (2.365, 'w'), (0.150, 'x'),
    (1.974, 'y'), (0.074, 'z') ]

def encode(frequencies):
    p = queue.PriorityQueue()
    for item in frequencies:
        p.put(item)

    #invariant that order is ascending in the priority queue
    #p.size() gives list of elements
    while p.qsize() > 1:
        left,right = p.get(),p.get()
        node = HuffmanNode(left,right)
        p.put((left[0]+right[0],node))
    return p.get()

node = encode(freq)
print(node[1].preorder())

"""
'''



Ans="""
'''

-- phpMyAdmin SQL Dump
-- version 3.4.5
-- http://www.phpmyadmin.net
--
-- Host: localhost
-- Generation Time: Jul 19, 2016 at 07:40 PM
-- Server version: 5.5.16
-- PHP Version: 5.4.0beta2-dev

SET SQL_MODE="NO_AUTO_VALUE_ON_ZERO";
SET time_zone = "+00:00";


/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;

--
-- Database: `test`
--

-- --------------------------------------------------------

--
-- Table structure for table `librarian`
--

CREATE TABLE IF NOT EXISTS `librarian` (
  `id` int(5) NOT NULL AUTO_INCREMENT,
  `name` varchar(100) NOT NULL,
  `password` varchar(100) NOT NULL,
  `email` varchar(100) NOT NULL,
  `address` varchar(200) NOT NULL,
  `city` varchar(100) NOT NULL,
  `contact` varchar(20) NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 AUTO_INCREMENT=7 ;

--
-- Dumping data for table `librarian`
--

INSERT INTO `librarian` (`id`, `name`, `password`, `email`, `address`, `city`, `contact`) VALUES
(1, 'Prabhakar', 'ppp', 'prabhakar@gmail.com', 'javatpoint', 'noida', '9998328238'),
(4, 'sumedh', 'sumesh', 'sumesh@gmail.com', 'Kuch Bhi', 'noida', '93823932823'),
(6, 'abhi', 'abhi', 'abhi@gmail.com', 'javatpoint', 'noida', '92393282323');

/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;

'''
"""



Ans="""
'''

import java.sql.Connection;
import java.sql.DriverManager;

public class DB {
	public static Connection getConnection(){
		Connection con=null;
		try{
			Class.forName("com.mysql.jdbc.Driver");
			con=DriverManager.getConnection("jdbc:mysql://localhost:3306/test","","");
		}catch(Exception e){System.out.println(e);}
		return con;
	}

}

'''
"""
